@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -54,7 +55,7 @@ class NUUser(NURESTObject):
     """ Represents a User in the VSD
 
         Notes:
-            Object that identifies the user functions.
+            Users represent people of your organization. A user can be placed into a group and this group can have some permissions to add VMs into a domain for instance.
     """
 
     __rest_name__ = "user"
@@ -214,7 +215,7 @@ class NUUser(NURESTObject):
         """ Get password value.
 
             Notes:
-                User password stored as a hash (SHA-1 encrpted)
+                User password in clear text. Password cannot be a single character asterisk (*)
 
                 
         """
@@ -225,7 +226,7 @@ class NUUser(NURESTObject):
         """ Set password value.
 
             Notes:
-                User password stored as a hash (SHA-1 encrpted)
+                User password in clear text. Password cannot be a single character asterisk (*)
 
                 
         """
