@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUPATNATPoolsFetcher
 
 
@@ -57,6 +58,9 @@ from .fetchers import NUUplinkConnectionsFetcher
 from .fetchers import NUBRConnectionsFetcher
 
 
+from .fetchers import NUStatisticsFetcher
+
+
 from .fetchers import NULtestatisticsFetcher
 
 
@@ -69,7 +73,7 @@ class NUVLAN(NURESTObject):
     """ Represents a VLAN in the VSD
 
         Notes:
-            Represents VLAN object under a given Port object.
+            VLANs are Virtual Local Area Networks. They allow to differentiate several traffic flows inside a single Port. A VLAN with a value set to 0 can be used to tell the system to not use any tagging.
     """
 
     __rest_name__ = "vlan"
@@ -80,9 +84,11 @@ class NUVLAN(NURESTObject):
     
     CONST_PERMITTED_ACTION_USE = "USE"
     
+    CONST_ASSOCIATED_CONNECTION_TYPE_UPLINK_CONNECTION = "UPLINK_CONNECTION"
+    
     CONST_PERMITTED_ACTION_READ = "READ"
     
-    CONST_STATUS_READY = "READY"
+    CONST_STATUS_ORPHAN = "ORPHAN"
     
     CONST_PERMITTED_ACTION_ALL = "ALL"
     
@@ -96,11 +102,21 @@ class NUVLAN(NURESTObject):
     
     CONST_STATUS_INITIALIZED = "INITIALIZED"
     
+    CONST_TYPE_DUC = "DUC"
+    
     CONST_STATUS_MISMATCH = "MISMATCH"
     
+    CONST_STATUS_READY = "READY"
+    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
-    CONST_STATUS_ORPHAN = "ORPHAN"
+    CONST_TYPE_ACCESS = "ACCESS"
+    
+    CONST_ASSOCIATED_CONNECTION_TYPE_BR_CONNECTION = "BR_CONNECTION"
+    
+    CONST_TYPE_BR = "BR"
+    
+    CONST_TYPE_UPLINK = "UPLINK"
     
     
 
@@ -129,17 +145,24 @@ class NUVLAN(NURESTObject):
         self._permitted_action = None
         self._description = None
         self._restricted = None
+        self._shunt_vlan = None
         self._entity_scope = None
         self._vport_id = None
+        self._is_uplink = None
         self._use_user_mnemonic = None
         self._user_mnemonic = None
         self._associated_bgp_profile_id = None
+        self._associated_connection_type = None
         self._associated_egress_qos_policy_id = None
+        self._associated_ingress_overlay_qo_s_policer_id = None
+        self._associated_ingress_qos_policy_id = None
+        self._associated_ingress_underlay_qo_s_policer_id = None
         self._associated_uplink_connection_id = None
         self._associated_vsc_profile_id = None
         self._status = None
         self._duc_vlan = None
         self._external_id = None
+        self._type = None
         
         self.expose_attribute(local_name="value", remote_name="value", attribute_type=int, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
@@ -149,17 +172,24 @@ class NUVLAN(NURESTObject):
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="restricted", remote_name="restricted", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="shunt_vlan", remote_name="shuntVLAN", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="vport_id", remote_name="vportID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="is_uplink", remote_name="isUplink", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_user_mnemonic", remote_name="useUserMnemonic", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_mnemonic", remote_name="userMnemonic", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_bgp_profile_id", remote_name="associatedBGPProfileID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_connection_type", remote_name="associatedConnectionType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BR_CONNECTION', u'UPLINK_CONNECTION'])
         self.expose_attribute(local_name="associated_egress_qos_policy_id", remote_name="associatedEgressQOSPolicyID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ingress_overlay_qo_s_policer_id", remote_name="associatedIngressOverlayQoSPolicerID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ingress_qos_policy_id", remote_name="associatedIngressQOSPolicyID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ingress_underlay_qo_s_policer_id", remote_name="associatedIngressUnderlayQoSPolicerID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_uplink_connection_id", remote_name="associatedUplinkConnectionID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_vsc_profile_id", remote_name="associatedVSCProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'INITIALIZED', u'MISMATCH', u'ORPHAN', u'READY'])
         self.expose_attribute(local_name="duc_vlan", remote_name="ducVlan", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'ACCESS', u'BR', u'DUC', u'UPLINK'])
         
 
         # Fetchers
@@ -195,6 +225,9 @@ class NUVLAN(NURESTObject):
         self.br_connections = NUBRConnectionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.statistics = NUStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ltestatistics = NULtestatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -260,7 +293,7 @@ class NUVLAN(NURESTObject):
         """ Get gateway_id value.
 
             Notes:
-                The Gateway associated with this  VLAN  . This is a read only attribute
+                The Gateway associated with this  VLAN. This is a read only attribute
 
                 
                 This attribute is named `gatewayID` in VSD API.
@@ -273,7 +306,7 @@ class NUVLAN(NURESTObject):
         """ Set gateway_id value.
 
             Notes:
-                The Gateway associated with this  VLAN  . This is a read only attribute
+                The Gateway associated with this  VLAN. This is a read only attribute
 
                 
                 This attribute is named `gatewayID` in VSD API.
@@ -364,7 +397,7 @@ class NUVLAN(NURESTObject):
         """ Get description value.
 
             Notes:
-                A description of the Port
+                A description of the VLAN instance.
 
                 
         """
@@ -375,7 +408,7 @@ class NUVLAN(NURESTObject):
         """ Set description value.
 
             Notes:
-                A description of the Port
+                A description of the VLAN instance.
 
                 
         """
@@ -405,6 +438,33 @@ class NUVLAN(NURESTObject):
         self._restricted = value
 
     
+    @property
+    def shunt_vlan(self):
+        """ Get shunt_vlan value.
+
+            Notes:
+                A flag to mark this instance of a VLAN as a candidate to be a termination point of a Shunt Link.  Only VLANs residing on a Network Port can have this attribute set to true.
+
+                
+                This attribute is named `shuntVLAN` in VSD API.
+                
+        """
+        return self._shunt_vlan
+
+    @shunt_vlan.setter
+    def shunt_vlan(self, value):
+        """ Set shunt_vlan value.
+
+            Notes:
+                A flag to mark this instance of a VLAN as a candidate to be a termination point of a Shunt Link.  Only VLANs residing on a Network Port can have this attribute set to true.
+
+                
+                This attribute is named `shuntVLAN` in VSD API.
+                
+        """
+        self._shunt_vlan = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -437,7 +497,7 @@ class NUVLAN(NURESTObject):
         """ Get vport_id value.
 
             Notes:
-                The Vport associated with this  VLAN  . This is a read only attribute
+                The Vport associated with this VLAN. This is a read only attribute
 
                 
                 This attribute is named `vportID` in VSD API.
@@ -450,7 +510,7 @@ class NUVLAN(NURESTObject):
         """ Set vport_id value.
 
             Notes:
-                The Vport associated with this  VLAN  . This is a read only attribute
+                The Vport associated with this VLAN. This is a read only attribute
 
                 
                 This attribute is named `vportID` in VSD API.
@@ -459,12 +519,39 @@ class NUVLAN(NURESTObject):
         self._vport_id = value
 
     
+    @property
+    def is_uplink(self):
+        """ Get is_uplink value.
+
+            Notes:
+                Indicates if the VLAN is used as an uplink.
+
+                
+                This attribute is named `isUplink` in VSD API.
+                
+        """
+        return self._is_uplink
+
+    @is_uplink.setter
+    def is_uplink(self, value):
+        """ Set is_uplink value.
+
+            Notes:
+                Indicates if the VLAN is used as an uplink.
+
+                
+                This attribute is named `isUplink` in VSD API.
+                
+        """
+        self._is_uplink = value
+
+    
     @property
     def use_user_mnemonic(self):
         """ Get use_user_mnemonic value.
 
             Notes:
-                determines whether to use user mnemonic of the Port
+                Determines whether to use the defined mnemonic for this VLAN instance.
 
                 
                 This attribute is named `useUserMnemonic` in VSD API.
@@ -477,7 +564,7 @@ class NUVLAN(NURESTObject):
         """ Set use_user_mnemonic value.
 
             Notes:
-                determines whether to use user mnemonic of the Port
+                Determines whether to use the defined mnemonic for this VLAN instance.
 
                 
                 This attribute is named `useUserMnemonic` in VSD API.
@@ -491,7 +578,7 @@ class NUVLAN(NURESTObject):
         """ Get user_mnemonic value.
 
             Notes:
-                user mnemonic of the Port
+                User mnemonic of the VLAN instance.
 
                 
                 This attribute is named `userMnemonic` in VSD API.
@@ -504,7 +591,7 @@ class NUVLAN(NURESTObject):
         """ Set user_mnemonic value.
 
             Notes:
-                user mnemonic of the Port
+                User mnemonic of the VLAN instance.
 
                 
                 This attribute is named `userMnemonic` in VSD API.
@@ -540,6 +627,33 @@ class NUVLAN(NURESTObject):
         self._associated_bgp_profile_id = value
 
     
+    @property
+    def associated_connection_type(self):
+        """ Get associated_connection_type value.
+
+            Notes:
+                Specifies the type of Connection (uplink, BR) associated to this VLAN instance.
+
+                
+                This attribute is named `associatedConnectionType` in VSD API.
+                
+        """
+        return self._associated_connection_type
+
+    @associated_connection_type.setter
+    def associated_connection_type(self, value):
+        """ Set associated_connection_type value.
+
+            Notes:
+                Specifies the type of Connection (uplink, BR) associated to this VLAN instance.
+
+                
+                This attribute is named `associatedConnectionType` in VSD API.
+                
+        """
+        self._associated_connection_type = value
+
+    
     @property
     def associated_egress_qos_policy_id(self):
         """ Get associated_egress_qos_policy_id value.
@@ -567,6 +681,87 @@ class NUVLAN(NURESTObject):
         self._associated_egress_qos_policy_id = value
 
     
+    @property
+    def associated_ingress_overlay_qo_s_policer_id(self):
+        """ Get associated_ingress_overlay_qo_s_policer_id value.
+
+            Notes:
+                ID of the Ingress Overlay QoS Policer associated with this VLAN.
+
+                
+                This attribute is named `associatedIngressOverlayQoSPolicerID` in VSD API.
+                
+        """
+        return self._associated_ingress_overlay_qo_s_policer_id
+
+    @associated_ingress_overlay_qo_s_policer_id.setter
+    def associated_ingress_overlay_qo_s_policer_id(self, value):
+        """ Set associated_ingress_overlay_qo_s_policer_id value.
+
+            Notes:
+                ID of the Ingress Overlay QoS Policer associated with this VLAN.
+
+                
+                This attribute is named `associatedIngressOverlayQoSPolicerID` in VSD API.
+                
+        """
+        self._associated_ingress_overlay_qo_s_policer_id = value
+
+    
+    @property
+    def associated_ingress_qos_policy_id(self):
+        """ Get associated_ingress_qos_policy_id value.
+
+            Notes:
+                ID of the Ingress QoS Policy / Tunnel Shaper associated with this VLAN.
+
+                
+                This attribute is named `associatedIngressQOSPolicyID` in VSD API.
+                
+        """
+        return self._associated_ingress_qos_policy_id
+
+    @associated_ingress_qos_policy_id.setter
+    def associated_ingress_qos_policy_id(self, value):
+        """ Set associated_ingress_qos_policy_id value.
+
+            Notes:
+                ID of the Ingress QoS Policy / Tunnel Shaper associated with this VLAN.
+
+                
+                This attribute is named `associatedIngressQOSPolicyID` in VSD API.
+                
+        """
+        self._associated_ingress_qos_policy_id = value
+
+    
+    @property
+    def associated_ingress_underlay_qo_s_policer_id(self):
+        """ Get associated_ingress_underlay_qo_s_policer_id value.
+
+            Notes:
+                ID of the Ingress Underlay QoS Policer associated with this VLAN.
+
+                
+                This attribute is named `associatedIngressUnderlayQoSPolicerID` in VSD API.
+                
+        """
+        return self._associated_ingress_underlay_qo_s_policer_id
+
+    @associated_ingress_underlay_qo_s_policer_id.setter
+    def associated_ingress_underlay_qo_s_policer_id(self, value):
+        """ Set associated_ingress_underlay_qo_s_policer_id value.
+
+            Notes:
+                ID of the Ingress Underlay QoS Policer associated with this VLAN.
+
+                
+                This attribute is named `associatedIngressUnderlayQoSPolicerID` in VSD API.
+                
+        """
+        self._associated_ingress_underlay_qo_s_policer_id = value
+
+    
     @property
     def associated_uplink_connection_id(self):
         """ Get associated_uplink_connection_id value.
@@ -698,6 +893,29 @@ class NUVLAN(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def type(self):
+        """ Get type value.
+
+            Notes:
+                This type marks a VLAN for its utility.
+
+                
+        """
+        return self._type
+
+    @type.setter
+    def type(self, value):
+        """ Set type value.
+
+            Notes:
+                This type marks a VLAN for its utility.
+
+                
+        """
+        self._type = value
+
+    
 
     
     ## Custom methods
