@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUVMResyncsFetcher
 
 
@@ -54,7 +55,7 @@ class NUVM(NURESTObject):
     """ Represents a VM in the VSD
 
         Notes:
-            Read only API that can retrieve the VMs associated with a domain, zone or subnet for mediation created VM's for REST created  VM's you need to set the additional proxy user header in http request : X-Nuage-ProxyUservalue of the header has to be either :1) enterpriseName@UserName (example : Alcatel Lucent@bob), or 2) external ID of user in VSD, typically is UUID generally decided by the CMS tool in questionUser needs to have CMS privileges to use proxy user header.
+            API that can retrieve the VMs associated with a domain, zone or subnet for mediation created VM's for REST created  VM's you need to set the additional proxy user header in http request : X-Nuage-ProxyUservalue of the header has to be either :1) enterpriseName@UserName (example : Alcatel Lucent@bob), or 2) external ID of user in VSD, typically is UUID generally decided by the CMS tool in questionUser needs to have CMS privileges to use proxy user header.
     """
 
     __rest_name__ = "vm"
@@ -203,6 +204,7 @@ class NUVM(NURESTObject):
         self._enterprise_name = None
         self._entity_scope = None
         self._domain_ids = None
+        self._compute_provisioned = None
         self._zone_ids = None
         self._orchestration_id = None
         self._user_id = None
@@ -227,6 +229,7 @@ class NUVM(NURESTObject):
         self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="domain_ids", remote_name="domainIDs", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="compute_provisioned", remote_name="computeProvisioned", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zone_ids", remote_name="zoneIDs", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="orchestration_id", remote_name="orchestrationID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_id", remote_name="userID", attribute_type=str, is_required=False, is_unique=False)
@@ -662,6 +665,33 @@ class NUVM(NURESTObject):
         self._domain_ids = value
 
     
+    @property
+    def compute_provisioned(self):
+        """ Get compute_provisioned value.
+
+            Notes:
+                computeProvisioned
+
+                
+                This attribute is named `computeProvisioned` in VSD API.
+                
+        """
+        return self._compute_provisioned
+
+    @compute_provisioned.setter
+    def compute_provisioned(self, value):
+        """ Set compute_provisioned value.
+
+            Notes:
+                computeProvisioned
+
+                
+                This attribute is named `computeProvisioned` in VSD API.
+                
+        """
+        self._compute_provisioned = value
+
+    
     @property
     def zone_ids(self):
         """ Get zone_ids value.
