@@ -141,12 +141,12 @@ class NUControllerVRSLink(NURESTObject):
         
         self._vrsid = None
         self._vrs_personality = None
+        self._vrs_system_id = None
         self._vsc_config_state = None
         self._vsc_current_state = None
         self._jsonrpc_connection_state = None
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._peer = None
         self._cluster_node_role = None
         self._embedded_metadata = None
@@ -155,20 +155,18 @@ class NUControllerVRSLink(NURESTObject):
         self._connections = None
         self._controller_id = None
         self._controller_type = None
-        self._creation_date = None
         self._status = None
-        self._owner = None
         self._external_id = None
         self._dynamic = None
         
         self.expose_attribute(local_name="vrsid", remote_name="VRSID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_personality", remote_name="VRSPersonality", attribute_type=str, is_required=False, is_unique=False, choices=[u'HARDWARE_VTEP', u'NONE', u'NSG', u'NSGBR', u'NSGDUC', u'NUAGE_210_WBX_32_Q', u'NUAGE_210_WBX_48_S', u'VRS', u'VRSB', u'VRSG'])
+        self.expose_attribute(local_name="vrs_system_id", remote_name="VRSSystemId", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vsc_config_state", remote_name="VSCConfigState", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'SECONDARY'])
         self.expose_attribute(local_name="vsc_current_state", remote_name="VSCCurrentState", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'SECONDARY'])
         self.expose_attribute(local_name="jsonrpc_connection_state", remote_name="JSONRPCConnectionState", attribute_type=str, is_required=False, is_unique=False, choices=[u'ADMIN_DOWN', u'DOWN', u'NONE', u'UP'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peer", remote_name="peer", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="cluster_node_role", remote_name="clusterNodeRole", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PRIMARY', u'SECONDARY'])
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
@@ -177,9 +175,7 @@ class NUControllerVRSLink(NURESTObject):
         self.expose_attribute(local_name="connections", remote_name="connections", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="controller_id", remote_name="controllerID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="controller_type", remote_name="controllerType", attribute_type=str, is_required=False, is_unique=False, choices=[u'HSC', u'VSC'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'ADMIN_DOWN', u'DOWN', u'UP'])
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="dynamic", remote_name="dynamic", attribute_type=bool, is_required=False, is_unique=False)
         
@@ -260,6 +256,33 @@ class NUControllerVRSLink(NURESTObject):
         self._vrs_personality = value
 
     
+    @property
+    def vrs_system_id(self):
+        """ Get vrs_system_id value.
+
+            Notes:
+                System ID of associated VRS
+
+                
+                This attribute is named `VRSSystemId` in VSD API.
+                
+        """
+        return self._vrs_system_id
+
+    @vrs_system_id.setter
+    def vrs_system_id(self, value):
+        """ Set vrs_system_id value.
+
+            Notes:
+                System ID of associated VRS
+
+                
+                This attribute is named `VRSSystemId` in VSD API.
+                
+        """
+        self._vrs_system_id = value
+
+    
     @property
     def vsc_config_state(self):
         """ Get vsc_config_state value.
@@ -391,33 +414,6 @@ class NUControllerVRSLink(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def peer(self):
         """ Get peer value.
@@ -622,33 +618,6 @@ class NUControllerVRSLink(NURESTObject):
         self._controller_type = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def status(self):
         """ Get status value.
@@ -672,29 +641,6 @@ class NUControllerVRSLink(NURESTObject):
         self._status = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
