@@ -154,6 +154,9 @@ from .fetchers import NUHostInterfacesFetcher
 from .fetchers import NURoutingPoliciesFetcher
 
 
+from .fetchers import NURoutingPolicyBindingsFetcher
+
+
 from .fetchers import NUSPATSourcesPoolsFetcher
 
 
@@ -233,7 +236,7 @@ class NUDomain(NURESTObject):
     
     CONST_POLICY_CHANGE_STATUS_DISCARDED = "DISCARDED"
     
-    CONST_FLOW_COLLECTION_ENABLED_DISABLED = "DISABLED"
+    CONST_THREAT_INTELLIGENCE_ENABLED_ENABLED = "ENABLED"
     
     CONST_DHCP_BEHAVIOR_UNDERLAY_RELAY = "UNDERLAY_RELAY"
     
@@ -243,6 +246,8 @@ class NUDomain(NURESTObject):
     
     CONST_TUNNEL_TYPE_VLAN = "VLAN"
     
+    CONST_THREAT_INTELLIGENCE_ENABLED_INHERITED = "INHERITED"
+    
     CONST_TUNNEL_TYPE_DC_DEFAULT = "DC_DEFAULT"
     
     CONST_MULTICAST_DISABLED = "DISABLED"
@@ -255,6 +260,8 @@ class NUDomain(NURESTObject):
     
     CONST_UPLINK_PREFERENCE_SYMMETRIC = "SYMMETRIC"
     
+    CONST_FLOW_COLLECTION_ENABLED_DISABLED = "DISABLED"
+    
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
     
     CONST_EVPNRT5_TYPE_MAC = "MAC"
@@ -311,6 +318,8 @@ class NUDomain(NURESTObject):
     
     CONST_POLICY_CHANGE_STATUS_APPLIED = "APPLIED"
     
+    CONST_THREAT_INTELLIGENCE_ENABLED_DISABLED = "DISABLED"
+    
     CONST_FIP_IGNORE_DEFAULT_ROUTE_ENABLED = "ENABLED"
     
     
@@ -351,7 +360,6 @@ class NUDomain(NURESTObject):
         self._maintenance_mode = None
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._advertise_criteria = None
         self._leaking_enabled = None
         self._secondary_dhcp_server_address = None
@@ -363,6 +371,7 @@ class NUDomain(NURESTObject):
         self._aggregate_flows_enabled = None
         self._aggregation_flow_type = None
         self._dhcp_server_addresses = None
+        self._threat_intelligence_enabled = None
         self._global_routing_enabled = None
         self._flow_collection_enabled = None
         self._embedded_metadata = None
@@ -381,8 +390,8 @@ class NUDomain(NURESTObject):
         self._route_target = None
         self._uplink_preference = None
         self._create_back_haul_subnet = None
-        self._creation_date = None
         self._associated_bgp_profile_id = None
+        self._associated_idp_profile_id = None
         self._associated_multicast_channel_map_id = None
         self._associated_pat_mapper_id = None
         self._associated_shared_pat_mapper_id = None
@@ -391,7 +400,6 @@ class NUDomain(NURESTObject):
         self._multicast = None
         self._tunnel_type = None
         self._customer_id = None
-        self._owner = None
         self._export_route_target = None
         self._external_id = None
         self._external_label = None
@@ -415,7 +423,6 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="maintenance_mode", remote_name="maintenanceMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="advertise_criteria", remote_name="advertiseCriteria", attribute_type=str, is_required=False, is_unique=False, choices=[u'HUB_ROUTES'])
         self.expose_attribute(local_name="leaking_enabled", remote_name="leakingEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_dhcp_server_address", remote_name="secondaryDHCPServerAddress", attribute_type=str, is_required=False, is_unique=False)
@@ -427,6 +434,7 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="aggregate_flows_enabled", remote_name="aggregateFlowsEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="aggregation_flow_type", remote_name="aggregationFlowType", attribute_type=str, is_required=False, is_unique=False, choices=[u'PBR_BASED', u'ROUTE_BASED'])
         self.expose_attribute(local_name="dhcp_server_addresses", remote_name="dhcpServerAddresses", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="threat_intelligence_enabled", remote_name="threatIntelligenceEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="global_routing_enabled", remote_name="globalRoutingEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="flow_collection_enabled", remote_name="flowCollectionEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
@@ -445,8 +453,8 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="route_target", remote_name="routeTarget", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="uplink_preference", remote_name="uplinkPreference", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'PRIMARY_SECONDARY', u'SECONDARY', u'SECONDARY_PRIMARY', u'SYMMETRIC'])
         self.expose_attribute(local_name="create_back_haul_subnet", remote_name="createBackHaulSubnet", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_bgp_profile_id", remote_name="associatedBGPProfileID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_idp_profile_id", remote_name="associatedIDPProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_pat_mapper_id", remote_name="associatedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_shared_pat_mapper_id", remote_name="associatedSharedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
@@ -455,7 +463,6 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="tunnel_type", remote_name="tunnelType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC_DEFAULT', u'GRE', u'MPLSoUDP', u'VLAN', u'VXLAN'])
         self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="export_route_target", remote_name="exportRouteTarget", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="external_label", remote_name="externalLabel", attribute_type=str, is_required=False, is_unique=False)
@@ -590,6 +597,9 @@ class NUDomain(NURESTObject):
         self.routing_policies = NURoutingPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.routing_policy_bindings = NURoutingPolicyBindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.spat_sources_pools = NUSPATSourcesPoolsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -1151,33 +1161,6 @@ class NUDomain(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def advertise_criteria(self):
         """ Get advertise_criteria value.
@@ -1471,6 +1454,33 @@ class NUDomain(NURESTObject):
         self._dhcp_server_addresses = value
 
     
+    @property
+    def threat_intelligence_enabled(self):
+        """ Get threat_intelligence_enabled value.
+
+            Notes:
+                Determines whether or not threat intelligence is enabled
+
+                
+                This attribute is named `threatIntelligenceEnabled` in VSD API.
+                
+        """
+        return self._threat_intelligence_enabled
+
+    @threat_intelligence_enabled.setter
+    def threat_intelligence_enabled(self, value):
+        """ Set threat_intelligence_enabled value.
+
+            Notes:
+                Determines whether or not threat intelligence is enabled
+
+                
+                This attribute is named `threatIntelligenceEnabled` in VSD API.
+                
+        """
+        self._threat_intelligence_enabled = value
+
+    
     @property
     def global_routing_enabled(self):
         """ Get global_routing_enabled value.
@@ -1949,33 +1959,6 @@ class NUDomain(NURESTObject):
         self._create_back_haul_subnet = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def associated_bgp_profile_id(self):
         """ Get associated_bgp_profile_id value.
@@ -2003,6 +1986,33 @@ class NUDomain(NURESTObject):
         self._associated_bgp_profile_id = value
 
     
+    @property
+    def associated_idp_profile_id(self):
+        """ Get associated_idp_profile_id value.
+
+            Notes:
+                The associated IDP Profile ID
+
+                
+                This attribute is named `associatedIDPProfileID` in VSD API.
+                
+        """
+        return self._associated_idp_profile_id
+
+    @associated_idp_profile_id.setter
+    def associated_idp_profile_id(self, value):
+        """ Set associated_idp_profile_id value.
+
+            Notes:
+                The associated IDP Profile ID
+
+                
+                This attribute is named `associatedIDPProfileID` in VSD API.
+                
+        """
+        self._associated_idp_profile_id = value
+
+    
     @property
     def associated_multicast_channel_map_id(self):
         """ Get associated_multicast_channel_map_id value.
@@ -2211,29 +2221,6 @@ class NUDomain(NURESTObject):
         self._customer_id = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def export_route_target(self):
         """ Get export_route_target value.
