@@ -70,6 +70,9 @@ from .fetchers import NUPATNATPoolsFetcher
 from .fetchers import NULDAPConfigurationsFetcher
 
 
+from .fetchers import NUIDPProfilesFetcher
+
+
 from .fetchers import NUWebCategoriesFetcher
 
 
@@ -172,6 +175,9 @@ from .fetchers import NUEnterpriseSecuritiesFetcher
 from .fetchers import NUJobsFetcher
 
 
+from .fetchers import NURolesFetcher
+
+
 from .fetchers import NUPolicyGroupCategoriesFetcher
 
 
@@ -276,46 +282,50 @@ class NUEnterprise(NURESTObject):
     
     CONST_ENCRYPTION_MANAGEMENT_MODE_MANAGED = "MANAGED"
     
-    CONST_FLOW_COLLECTION_ENABLED_ENABLED = "ENABLED"
+    CONST_ENCRYPTION_MANAGEMENT_MODE_DISABLED = "DISABLED"
+    
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
+    CONST_AVATAR_TYPE_URL = "URL"
+    
+    CONST_THREAT_INTELLIGENCE_ENABLED_ENABLED = "ENABLED"
     
     CONST_AVATAR_TYPE_COMPUTEDURL = "COMPUTEDURL"
     
-    CONST_ALLOWED_FORWARDING_MODE_LOCAL_AND_REMOTE = "LOCAL_AND_REMOTE"
-    
-    CONST_ALLOWED_FORWARDING_MODE_DISABLED = "DISABLED"
-    
-    CONST_ALLOWED_FORWARDING_CLASSES_NONE = "NONE"
-    
-    CONST_AVATAR_TYPE_BASE64 = "BASE64"
-    
-    CONST_ENCRYPTION_MANAGEMENT_MODE_DISABLED = "DISABLED"
-    
-    CONST_FLOW_COLLECTION_ENABLED_DISABLED = "DISABLED"
-    
-    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    CONST_ALLOWED_FORWARDING_CLASSES_F = "F"
     
     CONST_ALLOWED_FORWARDING_CLASSES_D = "D"
     
     CONST_ALLOWED_FORWARDING_CLASSES_E = "E"
     
-    CONST_ALLOWED_FORWARDING_CLASSES_F = "F"
+    CONST_FLOW_COLLECTION_ENABLED_DISABLED = "DISABLED"
     
     CONST_ALLOWED_FORWARDING_CLASSES_G = "G"
     
-    CONST_AVATAR_TYPE_URL = "URL"
-    
     CONST_ALLOWED_FORWARDING_CLASSES_A = "A"
     
     CONST_ALLOWED_FORWARDING_CLASSES_B = "B"
     
     CONST_ALLOWED_FORWARDING_CLASSES_C = "C"
     
-    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
-    
     CONST_ALLOWED_FORWARDING_CLASSES_H = "H"
     
+    CONST_ALLOWED_FORWARDING_MODE_DISABLED = "DISABLED"
+    
     CONST_ALLOWED_FORWARDING_MODE_LOCAL_ONLY = "LOCAL_ONLY"
     
+    CONST_FLOW_COLLECTION_ENABLED_ENABLED = "ENABLED"
+    
+    CONST_ALLOWED_FORWARDING_MODE_LOCAL_AND_REMOTE = "LOCAL_AND_REMOTE"
+    
+    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    
+    CONST_ALLOWED_FORWARDING_CLASSES_NONE = "NONE"
+    
+    CONST_AVATAR_TYPE_BASE64 = "BASE64"
+    
+    CONST_THREAT_INTELLIGENCE_ENABLED_DISABLED = "DISABLED"
+    
     
 
     def __init__(self, **kwargs):
@@ -342,12 +352,13 @@ class NUEnterprise(NURESTObject):
         self._vnf_management_enabled = None
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._web_filter_enabled = None
         self._receive_multi_cast_list_id = None
         self._send_multi_cast_list_id = None
         self._description = None
         self._shared_enterprise = None
+        self._threat_intelligence_enabled = None
+        self._threat_prevention_management_enabled = None
         self._dictionary_version = None
         self._virtual_firewall_rules_enabled = None
         self._allow_advanced_qos_configuration = None
@@ -365,7 +376,6 @@ class NUEnterprise(NURESTObject):
         self._entity_scope = None
         self._local_as = None
         self._forwarding_class = None
-        self._creation_date = None
         self._use_global_mac = None
         self._associated_enterprise_security_id = None
         self._associated_group_key_encryption_profile_id = None
@@ -373,7 +383,6 @@ class NUEnterprise(NURESTObject):
         self._customer_id = None
         self._avatar_data = None
         self._avatar_type = None
-        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="ldap_authorization_enabled", remote_name="LDAPAuthorizationEnabled", attribute_type=bool, is_required=False, is_unique=False)
@@ -383,12 +392,13 @@ class NUEnterprise(NURESTObject):
         self.expose_attribute(local_name="vnf_management_enabled", remote_name="VNFManagementEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="web_filter_enabled", remote_name="webFilterEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="receive_multi_cast_list_id", remote_name="receiveMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="send_multi_cast_list_id", remote_name="sendMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="shared_enterprise", remote_name="sharedEnterprise", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="threat_intelligence_enabled", remote_name="threatIntelligenceEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
+        self.expose_attribute(local_name="threat_prevention_management_enabled", remote_name="threatPreventionManagementEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dictionary_version", remote_name="dictionaryVersion", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="virtual_firewall_rules_enabled", remote_name="virtualFirewallRulesEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_advanced_qos_configuration", remote_name="allowAdvancedQOSConfiguration", attribute_type=bool, is_required=False, is_unique=False)
@@ -406,7 +416,6 @@ class NUEnterprise(NURESTObject):
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="local_as", remote_name="localAS", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="forwarding_class", remote_name="forwardingClass", attribute_type=list, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_enterprise_security_id", remote_name="associatedEnterpriseSecurityID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_group_key_encryption_profile_id", remote_name="associatedGroupKeyEncryptionProfileID", attribute_type=str, is_required=False, is_unique=False)
@@ -414,7 +423,6 @@ class NUEnterprise(NURESTObject):
         self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="avatar_data", remote_name="avatarData", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="avatar_type", remote_name="avatarType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BASE64', u'COMPUTEDURL', u'URL'])
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -463,6 +471,9 @@ class NUEnterprise(NURESTObject):
         self.ldap_configurations = NULDAPConfigurationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.idp_profiles = NUIDPProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.web_categories = NUWebCategoriesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -565,6 +576,9 @@ class NUEnterprise(NURESTObject):
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.roles = NURolesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.policy_group_categories = NUPolicyGroupCategoriesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -841,33 +855,6 @@ class NUEnterprise(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def web_filter_enabled(self):
         """ Get web_filter_enabled value.
@@ -999,6 +986,60 @@ class NUEnterprise(NURESTObject):
         self._shared_enterprise = value
 
     
+    @property
+    def threat_intelligence_enabled(self):
+        """ Get threat_intelligence_enabled value.
+
+            Notes:
+                Determines whether or not threat intelligence is enabled
+
+                
+                This attribute is named `threatIntelligenceEnabled` in VSD API.
+                
+        """
+        return self._threat_intelligence_enabled
+
+    @threat_intelligence_enabled.setter
+    def threat_intelligence_enabled(self, value):
+        """ Set threat_intelligence_enabled value.
+
+            Notes:
+                Determines whether or not threat intelligence is enabled
+
+                
+                This attribute is named `threatIntelligenceEnabled` in VSD API.
+                
+        """
+        self._threat_intelligence_enabled = value
+
+    
+    @property
+    def threat_prevention_management_enabled(self):
+        """ Get threat_prevention_management_enabled value.
+
+            Notes:
+                Threat Prevention Management enabled for enterprise
+
+                
+                This attribute is named `threatPreventionManagementEnabled` in VSD API.
+                
+        """
+        return self._threat_prevention_management_enabled
+
+    @threat_prevention_management_enabled.setter
+    def threat_prevention_management_enabled(self, value):
+        """ Set threat_prevention_management_enabled value.
+
+            Notes:
+                Threat Prevention Management enabled for enterprise
+
+                
+                This attribute is named `threatPreventionManagementEnabled` in VSD API.
+                
+        """
+        self._threat_prevention_management_enabled = value
+
+    
     @property
     def dictionary_version(self):
         """ Get dictionary_version value.
@@ -1458,33 +1499,6 @@ class NUEnterprise(NURESTObject):
         self._forwarding_class = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def use_global_mac(self):
         """ Get use_global_mac value.
@@ -1674,29 +1688,6 @@ class NUEnterprise(NURESTObject):
         self._avatar_type = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
