@@ -67,7 +67,7 @@ class NUHSC(NURESTObject):
     
     ## Constants
     
-    CONST_TYPE_NUAGE_210_WBX_48_S = "NUAGE_210_WBX_48_S"
+    CONST_TYPE_VSG = "VSG"
     
     CONST_STATUS_DOWN = "DOWN"
     
@@ -83,12 +83,8 @@ class NUHSC(NURESTObject):
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
-    CONST_TYPE_VSG = "VSG"
-    
     CONST_STATUS_ADMIN_DOWN = "ADMIN_DOWN"
     
-    CONST_TYPE_NUAGE_210_WBX_32_Q = "NUAGE_210_WBX_32_Q"
-    
     
 
     def __init__(self, **kwargs):
@@ -112,8 +108,6 @@ class NUHSC(NURESTObject):
         self._management_ip = None
         self._last_state_change = None
         self._last_updated_by = None
-        self._last_updated_date = None
-        self._address = None
         self._addresses = None
         self._peak_cpuusage = None
         self._peak_memory_usage = None
@@ -126,7 +120,7 @@ class NUHSC(NURESTObject):
         self._entity_scope = None
         self._location = None
         self._model = None
-        self._creation_date = None
+        self._communication_id = None
         self._product_version = None
         self._vsds = None
         self._status = None
@@ -134,7 +128,6 @@ class NUHSC(NURESTObject):
         self._current_memory_usage = None
         self._average_cpuusage = None
         self._average_memory_usage = None
-        self._owner = None
         self._external_id = None
         self._type = None
         
@@ -142,8 +135,6 @@ class NUHSC(NURESTObject):
         self.expose_attribute(local_name="management_ip", remote_name="managementIP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_state_change", remote_name="lastStateChange", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="addresses", remote_name="addresses", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak_cpuusage", remote_name="peakCPUUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak_memory_usage", remote_name="peakMemoryUsage", attribute_type=float, is_required=False, is_unique=False)
@@ -156,7 +147,7 @@ class NUHSC(NURESTObject):
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="location", remote_name="location", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="model", remote_name="model", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="communication_id", remote_name="communicationId", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="product_version", remote_name="productVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vsds", remote_name="vsds", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'ADMIN_DOWN', u'DOWN', u'UP'])
@@ -164,9 +155,8 @@ class NUHSC(NURESTObject):
         self.expose_attribute(local_name="current_memory_usage", remote_name="currentMemoryUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="average_cpuusage", remote_name="averageCPUUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="average_memory_usage", remote_name="averageMemoryUsage", attribute_type=float, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
-        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC7X50', u'NONE', u'NUAGE_210_WBX_32_Q', u'NUAGE_210_WBX_48_S', u'VSA', u'VSG'])
+        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC7X50', u'NONE', u'VSA', u'VSG'])
         
 
         # Fetchers
@@ -304,56 +294,6 @@ class NUHSC(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
-    @property
-    def address(self):
-        """ Get address value.
-
-            Notes:
-                The IP of the VRS entity
-
-                
-        """
-        return self._address
-
-    @address.setter
-    def address(self, value):
-        """ Set address value.
-
-            Notes:
-                The IP of the VRS entity
-
-                
-        """
-        self._address = value
-
-    
     @property
     def addresses(self):
         """ Get addresses value.
@@ -655,30 +595,30 @@ class NUHSC(NURESTObject):
 
     
     @property
-    def creation_date(self):
-        """ Get creation_date value.
+    def communication_id(self):
+        """ Get communication_id value.
 
             Notes:
-                Time stamp when this object was created.
+                Communication identifier used to uniquely identify the HSC connected to VSD
 
                 
-                This attribute is named `creationDate` in VSD API.
+                This attribute is named `communicationId` in VSD API.
                 
         """
-        return self._creation_date
+        return self._communication_id
 
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
+    @communication_id.setter
+    def communication_id(self, value):
+        """ Set communication_id value.
 
             Notes:
-                Time stamp when this object was created.
+                Communication identifier used to uniquely identify the HSC connected to VSD
 
                 
-                This attribute is named `creationDate` in VSD API.
+                This attribute is named `communicationId` in VSD API.
                 
         """
-        self._creation_date = value
+        self._communication_id = value
 
     
     @property
@@ -862,29 +802,6 @@ class NUHSC(NURESTObject):
         self._average_memory_usage = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
