@@ -107,36 +107,30 @@ class NULink(NURESTObject):
         # Read/Write Attributes
         
         self._last_updated_by = None
-        self._last_updated_date = None
         self._acceptance_criteria = None
         self._read_only = None
         self._embedded_metadata = None
         self._entity_scope = None
-        self._creation_date = None
         self._associated_destination_id = None
         self._associated_destination_name = None
         self._associated_destination_type = None
         self._associated_source_id = None
         self._associated_source_name = None
         self._associated_source_type = None
-        self._owner = None
         self._external_id = None
         self._type = None
         
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="acceptance_criteria", remote_name="acceptanceCriteria", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'SUBNETS_ONLY'])
         self.expose_attribute(local_name="read_only", remote_name="readOnly", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_destination_id", remote_name="associatedDestinationID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_destination_name", remote_name="associatedDestinationName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_destination_type", remote_name="associatedDestinationType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DOMAIN'])
         self.expose_attribute(local_name="associated_source_id", remote_name="associatedSourceID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_source_name", remote_name="associatedSourceName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_source_type", remote_name="associatedSourceType", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'BIDIR', u'BORDER_ROUTER', u'HUB_AND_SPOKE', u'OVERLAY_ADDRESS_TRANSLATION', u'SERVICE_CHAINING'])
         
@@ -199,33 +193,6 @@ class NULink(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def acceptance_criteria(self):
         """ Get acceptance_criteria value.
@@ -334,33 +301,6 @@ class NULink(NURESTObject):
         self._entity_scope = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def associated_destination_id(self):
         """ Get associated_destination_id value.
@@ -523,29 +463,6 @@ class NULink(NURESTObject):
         self._associated_source_type = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
@@ -578,7 +495,7 @@ class NULink(NURESTObject):
         """ Get type value.
 
             Notes:
-                This is used to distinguish between different type of links: hub and spoke, ip address, VNS border router links.
+                This is used to distinguish between different type of links: hub and spoke, IP address, VNS border router links.
 
                 
         """
@@ -589,7 +506,7 @@ class NULink(NURESTObject):
         """ Set type value.
 
             Notes:
-                This is used to distinguish between different type of links: hub and spoke, ip address, VNS border router links.
+                This is used to distinguish between different type of links: hub and spoke, IP address, VNS border router links.
 
                 
         """
