@@ -43,6 +43,9 @@ from .fetchers import NUPermissionsFetcher
 from .fetchers import NUMetadatasFetcher
 
 
+from .fetchers import NUThreatPreventionInfosFetcher
+
+
 from .fetchers import NUWirelessPortsFetcher
 
 
@@ -52,6 +55,9 @@ from .fetchers import NUAlarmsFetcher
 from .fetchers import NUGlobalMetadatasFetcher
 
 
+from .fetchers import NUUnderlayTestsFetcher
+
+
 from .fetchers import NUVNFsFetcher
 
 
@@ -297,6 +303,7 @@ class NUNSGateway(NURESTObject):
         self._sku = None
         self._tpm_status = None
         self._tpm_version = None
+        self._cpu_core_allocation = None
         self._cpu_type = None
         self._vsdaar_application_version = None
         self._nsg_version = None
@@ -306,7 +313,6 @@ class NUNSGateway(NURESTObject):
         self._family = None
         self._last_configuration_reload_timestamp = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._datapath_id = None
         self._gateway_config_raw_version = None
         self._gateway_config_version = None
@@ -318,8 +324,10 @@ class NUNSGateway(NURESTObject):
         self._derived_ssh_service_state = None
         self._permitted_action = None
         self._personality = None
+        self._cert_validity_days = None
         self._description = None
         self._network_acceleration = None
+        self._threat_prevention_enabled = None
         self._libraries = None
         self._embedded_metadata = None
         self._inherited_ssh_service_state = None
@@ -335,17 +343,16 @@ class NUNSGateway(NURESTObject):
         self._bootstrap_status = None
         self._operation_mode = None
         self._operation_status = None
-        self._creation_date = None
         self._product_name = None
         self._associated_gateway_security_id = None
         self._associated_gateway_security_profile_id = None
         self._associated_nsg_info_id = None
         self._associated_nsg_upgrade_profile_id = None
         self._associated_overlay_management_profile_id = None
+        self._huge_page_setting = None
         self._functions = None
         self._tunnel_shaping = None
         self._auto_disc_gateway_id = None
-        self._owner = None
         self._external_id = None
         self._syslog_level = None
         self._system_id = None
@@ -363,6 +370,7 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="sku", remote_name="SKU", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="tpm_status", remote_name="TPMStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED_NOT_OPERATIONAL', u'ENABLED_OPERATIONAL', u'UNKNOWN'])
         self.expose_attribute(local_name="tpm_version", remote_name="TPMVersion", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="cpu_core_allocation", remote_name="CPUCoreAllocation", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="cpu_type", remote_name="CPUType", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vsdaar_application_version", remote_name="VSDAARApplicationVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nsg_version", remote_name="NSGVersion", attribute_type=str, is_required=False, is_unique=False)
@@ -372,7 +380,6 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="family", remote_name="family", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'NSG_AMI', u'NSG_AZ', u'NSG_C', u'NSG_E', u'NSG_E200', u'NSG_E300', u'NSG_V', u'NSG_X', u'NSG_X200'])
         self.expose_attribute(local_name="last_configuration_reload_timestamp", remote_name="lastConfigurationReloadTimestamp", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_id", remote_name="datapathID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_config_raw_version", remote_name="gatewayConfigRawVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_config_version", remote_name="gatewayConfigVersion", attribute_type=str, is_required=False, is_unique=False)
@@ -384,8 +391,10 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="derived_ssh_service_state", remote_name="derivedSSHServiceState", attribute_type=str, is_required=False, is_unique=False, choices=[u'INHERITED_DISABLED', u'INHERITED_ENABLED', u'INSTANCE_DISABLED', u'INSTANCE_ENABLED', u'UNKNOWN'])
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'NSG', u'NSGBR', u'NSGDUC'])
+        self.expose_attribute(local_name="cert_validity_days", remote_name="certValidityDays", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="network_acceleration", remote_name="networkAcceleration", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PERFORMANCE', u'SESSION_OPTIMIZED', u'VNF_AWARE'])
+        self.expose_attribute(local_name="threat_prevention_enabled", remote_name="threatPreventionEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="libraries", remote_name="libraries", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="inherited_ssh_service_state", remote_name="inheritedSSHServiceState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
@@ -401,17 +410,16 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="bootstrap_status", remote_name="bootstrapStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'ACTIVE', u'CERTIFICATE_SIGNED', u'INACTIVE', u'NOTIFICATION_APP_REQ_ACK', u'NOTIFICATION_APP_REQ_SENT', u'QUARANTINED', u'REVOKED'])
         self.expose_attribute(local_name="operation_mode", remote_name="operationMode", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="operation_status", remote_name="operationStatus", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="product_name", remote_name="productName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_gateway_security_id", remote_name="associatedGatewaySecurityID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_gateway_security_profile_id", remote_name="associatedGatewaySecurityProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_nsg_info_id", remote_name="associatedNSGInfoID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_nsg_upgrade_profile_id", remote_name="associatedNSGUpgradeProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_overlay_management_profile_id", remote_name="associatedOverlayManagementProfileID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="huge_page_setting", remote_name="hugePageSetting", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="functions", remote_name="functions", attribute_type=list, is_required=False, is_unique=False, choices=[u'GATEWAY', u'HUB', u'UBR'])
         self.expose_attribute(local_name="tunnel_shaping", remote_name="tunnelShaping", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="auto_disc_gateway_id", remote_name="autoDiscGatewayID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="syslog_level", remote_name="syslogLevel", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALERT', u'CRITICAL', u'EMERGENCY', u'ERROR', u'INFO', u'NOTICE', u'WARNING'])
         self.expose_attribute(local_name="system_id", remote_name="systemID", attribute_type=str, is_required=False, is_unique=False)
@@ -435,6 +443,9 @@ class NUNSGateway(NURESTObject):
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.threat_prevention_infos = NUThreatPreventionInfosFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.wireless_ports = NUWirelessPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -444,6 +455,9 @@ class NUNSGateway(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.underlay_tests = NUUnderlayTestsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.vnfs = NUVNFsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -847,6 +861,33 @@ class NUNSGateway(NURESTObject):
         self._tpm_version = value
 
     
+    @property
+    def cpu_core_allocation(self):
+        """ Get cpu_core_allocation value.
+
+            Notes:
+                Current CPU allocation for network accelerated gateways.  Displays total number of cores and those isolated.
+
+                
+                This attribute is named `CPUCoreAllocation` in VSD API.
+                
+        """
+        return self._cpu_core_allocation
+
+    @cpu_core_allocation.setter
+    def cpu_core_allocation(self, value):
+        """ Set cpu_core_allocation value.
+
+            Notes:
+                Current CPU allocation for network accelerated gateways.  Displays total number of cores and those isolated.
+
+                
+                This attribute is named `CPUCoreAllocation` in VSD API.
+                
+        """
+        self._cpu_core_allocation = value
+
+    
     @property
     def cpu_type(self):
         """ Get cpu_type value.
@@ -1082,33 +1123,6 @@ class NUNSGateway(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def datapath_id(self):
         """ Get datapath_id value.
@@ -1398,6 +1412,33 @@ class NUNSGateway(NURESTObject):
         self._personality = value
 
     
+    @property
+    def cert_validity_days(self):
+        """ Get cert_validity_days value.
+
+            Notes:
+                The number of days for which the NSG's certificate is valid.
+
+                
+                This attribute is named `certValidityDays` in VSD API.
+                
+        """
+        return self._cert_validity_days
+
+    @cert_validity_days.setter
+    def cert_validity_days(self, value):
+        """ Set cert_validity_days value.
+
+            Notes:
+                The number of days for which the NSG's certificate is valid.
+
+                
+                This attribute is named `certValidityDays` in VSD API.
+                
+        """
+        self._cert_validity_days = value
+
+    
     @property
     def description(self):
         """ Get description value.
@@ -1448,6 +1489,33 @@ class NUNSGateway(NURESTObject):
         self._network_acceleration = value
 
     
+    @property
+    def threat_prevention_enabled(self):
+        """ Get threat_prevention_enabled value.
+
+            Notes:
+                Indicates if Threat Prevention capability enabled on NSG.
+
+                
+                This attribute is named `threatPreventionEnabled` in VSD API.
+                
+        """
+        return self._threat_prevention_enabled
+
+    @threat_prevention_enabled.setter
+    def threat_prevention_enabled(self, value):
+        """ Set threat_prevention_enabled value.
+
+            Notes:
+                Indicates if Threat Prevention capability enabled on NSG.
+
+                
+                This attribute is named `threatPreventionEnabled` in VSD API.
+                
+        """
+        self._threat_prevention_enabled = value
+
+    
     @property
     def libraries(self):
         """ Get libraries value.
@@ -1849,33 +1917,6 @@ class NUNSGateway(NURESTObject):
         self._operation_status = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def product_name(self):
         """ Get product_name value.
@@ -2038,6 +2079,33 @@ class NUNSGateway(NURESTObject):
         self._associated_overlay_management_profile_id = value
 
     
+    @property
+    def huge_page_setting(self):
+        """ Get huge_page_setting value.
+
+            Notes:
+                The size and number of huge pages for an NSG that is running in network accelerated mode.  Hugepage values states the portion of memory reserved for network accelerated services.
+
+                
+                This attribute is named `hugePageSetting` in VSD API.
+                
+        """
+        return self._huge_page_setting
+
+    @huge_page_setting.setter
+    def huge_page_setting(self, value):
+        """ Set huge_page_setting value.
+
+            Notes:
+                The size and number of huge pages for an NSG that is running in network accelerated mode.  Hugepage values states the portion of memory reserved for network accelerated services.
+
+                
+                This attribute is named `hugePageSetting` in VSD API.
+                
+        """
+        self._huge_page_setting = value
+
+    
     @property
     def functions(self):
         """ Get functions value.
@@ -2115,29 +2183,6 @@ class NUNSGateway(NURESTObject):
         self._auto_disc_gateway_id = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
