@@ -86,10 +86,10 @@ class NUOSPFInterface(NURESTObject):
 
         # Read/Write Attributes
         
+        self._bfd_enabled = None
         self._name = None
         self._passive_enabled = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._admin_state = None
         self._dead_interval = None
         self._hello_interval = None
@@ -99,19 +99,17 @@ class NUOSPFInterface(NURESTObject):
         self._embedded_metadata = None
         self._interface_type = None
         self._entity_scope = None
-        self._creation_date = None
         self._priority = None
         self._associated_subnet_id = None
         self._mtu = None
         self._authentication_key = None
         self._authentication_type = None
-        self._owner = None
         self._external_id = None
         
+        self.expose_attribute(local_name="bfd_enabled", remote_name="BFDEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="passive_enabled", remote_name="passiveEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="admin_state", remote_name="adminState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DOWN', u'UP'])
         self.expose_attribute(local_name="dead_interval", remote_name="deadInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="hello_interval", remote_name="helloInterval", attribute_type=int, is_required=False, is_unique=False)
@@ -121,13 +119,11 @@ class NUOSPFInterface(NURESTObject):
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="interface_type", remote_name="interfaceType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BROADCAST', u'POINT_TO_POINT'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="priority", remote_name="priority", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_subnet_id", remote_name="associatedSubnetID", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="mtu", remote_name="mtu", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="authentication_key", remote_name="authenticationKey", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="authentication_type", remote_name="authenticationType", attribute_type=str, is_required=False, is_unique=False, choices=[u'MESSAGE_DIGEST', u'NONE', u'PASSWORD'])
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -144,6 +140,33 @@ class NUOSPFInterface(NURESTObject):
 
     # Properties
     
+    @property
+    def bfd_enabled(self):
+        """ Get bfd_enabled value.
+
+            Notes:
+                Enable or disable Bidirectional Forwarding Detection for this OSPF Interface.
+
+                
+                This attribute is named `BFDEnabled` in VSD API.
+                
+        """
+        return self._bfd_enabled
+
+    @bfd_enabled.setter
+    def bfd_enabled(self, value):
+        """ Set bfd_enabled value.
+
+            Notes:
+                Enable or disable Bidirectional Forwarding Detection for this OSPF Interface.
+
+                
+                This attribute is named `BFDEnabled` in VSD API.
+                
+        """
+        self._bfd_enabled = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -221,33 +244,6 @@ class NUOSPFInterface(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def admin_state(self):
         """ Get admin_state value.
@@ -483,33 +479,6 @@ class NUOSPFInterface(NURESTObject):
         self._entity_scope = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def priority(self):
         """ Get priority value.
@@ -637,29 +606,6 @@ class NUOSPFInterface(NURESTObject):
         self._authentication_type = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
