@@ -116,7 +116,6 @@ class NUPort(NURESTObject):
         self._vlan_range = None
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._template_id = None
         self._permitted_action = None
         self._description = None
@@ -124,20 +123,21 @@ class NUPort(NURESTObject):
         self._embedded_metadata = None
         self._entity_scope = None
         self._port_type = None
-        self._creation_date = None
         self._is_resilient = None
         self._use_user_mnemonic = None
         self._user_mnemonic = None
         self._associated_egress_qos_policy_id = None
+        self._associated_ethernet_segment_group_id = None
+        self._associated_ethernet_segment_id = None
+        self._associated_ethernet_segment_vlan_range = None
+        self._associated_ethernet_segment_virtual = None
         self._associated_redundant_port_id = None
         self._status = None
-        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="vlan_range", remote_name="VLANRange", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="template_id", remote_name="templateID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -145,14 +145,16 @@ class NUPort(NURESTObject):
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS', u'MANAGEMENT', u'NETWORK'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="is_resilient", remote_name="isResilient", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_user_mnemonic", remote_name="useUserMnemonic", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_mnemonic", remote_name="userMnemonic", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_egress_qos_policy_id", remote_name="associatedEgressQOSPolicyID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ethernet_segment_group_id", remote_name="associatedEthernetSegmentGroupID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ethernet_segment_id", remote_name="associatedEthernetSegmentID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ethernet_segment_vlan_range", remote_name="associatedEthernetSegmentVLANRange", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ethernet_segment_virtual", remote_name="associatedEthernetSegmentVirtual", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_redundant_port_id", remote_name="associatedRedundantPortID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'INITIALIZED', u'MISMATCH', u'ORPHAN', u'READY'])
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -261,33 +263,6 @@ class NUPort(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def template_id(self):
         """ Get template_id value.
@@ -473,33 +448,6 @@ class NUPort(NURESTObject):
         self._port_type = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def is_resilient(self):
         """ Get is_resilient value.
@@ -608,6 +556,114 @@ class NUPort(NURESTObject):
         self._associated_egress_qos_policy_id = value
 
     
+    @property
+    def associated_ethernet_segment_group_id(self):
+        """ Get associated_ethernet_segment_group_id value.
+
+            Notes:
+                ID of the Ethernet Segment Group to which this Port instance may be associated to.
+
+                
+                This attribute is named `associatedEthernetSegmentGroupID` in VSD API.
+                
+        """
+        return self._associated_ethernet_segment_group_id
+
+    @associated_ethernet_segment_group_id.setter
+    def associated_ethernet_segment_group_id(self, value):
+        """ Set associated_ethernet_segment_group_id value.
+
+            Notes:
+                ID of the Ethernet Segment Group to which this Port instance may be associated to.
+
+                
+                This attribute is named `associatedEthernetSegmentGroupID` in VSD API.
+                
+        """
+        self._associated_ethernet_segment_group_id = value
+
+    
+    @property
+    def associated_ethernet_segment_id(self):
+        """ Get associated_ethernet_segment_id value.
+
+            Notes:
+                Identifier of the Ethernet Segment to which this Port is associated to.
+
+                
+                This attribute is named `associatedEthernetSegmentID` in VSD API.
+                
+        """
+        return self._associated_ethernet_segment_id
+
+    @associated_ethernet_segment_id.setter
+    def associated_ethernet_segment_id(self, value):
+        """ Set associated_ethernet_segment_id value.
+
+            Notes:
+                Identifier of the Ethernet Segment to which this Port is associated to.
+
+                
+                This attribute is named `associatedEthernetSegmentID` in VSD API.
+                
+        """
+        self._associated_ethernet_segment_id = value
+
+    
+    @property
+    def associated_ethernet_segment_vlan_range(self):
+        """ Get associated_ethernet_segment_vlan_range value.
+
+            Notes:
+                VLAN Range of the associated Ethernet Segment. Format must conform to a-b,c,d-f where a,b,c,d,f are integers between 0 and 4095.
+
+                
+                This attribute is named `associatedEthernetSegmentVLANRange` in VSD API.
+                
+        """
+        return self._associated_ethernet_segment_vlan_range
+
+    @associated_ethernet_segment_vlan_range.setter
+    def associated_ethernet_segment_vlan_range(self, value):
+        """ Set associated_ethernet_segment_vlan_range value.
+
+            Notes:
+                VLAN Range of the associated Ethernet Segment. Format must conform to a-b,c,d-f where a,b,c,d,f are integers between 0 and 4095.
+
+                
+                This attribute is named `associatedEthernetSegmentVLANRange` in VSD API.
+                
+        """
+        self._associated_ethernet_segment_vlan_range = value
+
+    
+    @property
+    def associated_ethernet_segment_virtual(self):
+        """ Get associated_ethernet_segment_virtual value.
+
+            Notes:
+                Indicates if associated Ethernet Segment is virtual.
+
+                
+                This attribute is named `associatedEthernetSegmentVirtual` in VSD API.
+                
+        """
+        return self._associated_ethernet_segment_virtual
+
+    @associated_ethernet_segment_virtual.setter
+    def associated_ethernet_segment_virtual(self, value):
+        """ Set associated_ethernet_segment_virtual value.
+
+            Notes:
+                Indicates if associated Ethernet Segment is virtual.
+
+                
+                This attribute is named `associatedEthernetSegmentVirtual` in VSD API.
+                
+        """
+        self._associated_ethernet_segment_virtual = value
+
+    
     @property
     def associated_redundant_port_id(self):
         """ Get associated_redundant_port_id value.
@@ -658,29 +714,6 @@ class NUPort(NURESTObject):
         self._status = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
