@@ -98,7 +98,6 @@ class NURedirectionTarget(NURESTObject):
         self._esi = None
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._redundancy_enabled = None
         self._template_id = None
         self._description = None
@@ -107,15 +106,13 @@ class NURedirectionTarget(NURESTObject):
         self._embedded_metadata = None
         self._end_point_type = None
         self._entity_scope = None
-        self._creation_date = None
         self._trigger_type = None
-        self._owner = None
+        self._auto_created = None
         self._external_id = None
         
         self.expose_attribute(local_name="esi", remote_name="ESI", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="redundancy_enabled", remote_name="redundancyEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="template_id", remote_name="templateID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -124,9 +121,8 @@ class NURedirectionTarget(NURESTObject):
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="end_point_type", remote_name="endPointType", attribute_type=str, is_required=True, is_unique=False, choices=[u'L3', u'NSG_VNF', u'VIRTUAL_WIRE'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="trigger_type", remote_name="triggerType", attribute_type=str, is_required=False, is_unique=False, choices=[u'GARP', u'NONE'])
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="auto_created", remote_name="autoCreated", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -229,33 +225,6 @@ class NURedirectionTarget(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def redundancy_enabled(self):
         """ Get redundancy_enabled value.
@@ -468,33 +437,6 @@ class NURedirectionTarget(NURESTObject):
         self._entity_scope = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def trigger_type(self):
         """ Get trigger_type value.
@@ -523,26 +465,30 @@ class NURedirectionTarget(NURESTObject):
 
     
     @property
-    def owner(self):
-        """ Get owner value.
+    def auto_created(self):
+        """ Get auto_created value.
 
             Notes:
-                Identifies the user that has created this object.
+                Indicates if redirection target was auto created by the system
 
                 
+                This attribute is named `autoCreated` in VSD API.
+                
         """
-        return self._owner
+        return self._auto_created
 
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
+    @auto_created.setter
+    def auto_created(self, value):
+        """ Set auto_created value.
 
             Notes:
-                Identifies the user that has created this object.
+                Indicates if redirection target was auto created by the system
 
                 
+                This attribute is named `autoCreated` in VSD API.
+                
         """
-        self._owner = value
+        self._auto_created = value
 
     
     @property
