@@ -73,6 +73,9 @@ from .fetchers import NUVMsFetcher
 from .fetchers import NUVMInterfacesFetcher
 
 
+from .fetchers import NUVMIPReservationsFetcher
+
+
 from .fetchers import NUEnterprisePermissionsFetcher
 
 
@@ -151,10 +154,14 @@ class NUSubnet(NURESTObject):
     
     CONST_MAINTENANCE_MODE_ENABLED = "ENABLED"
     
+    CONST_L2_ENCAP_TYPE_VLAN = "VLAN"
+    
     CONST_RESOURCE_TYPE_PUBLIC = "PUBLIC"
     
     CONST_UNDERLAY_ENABLED_INHERITED = "INHERITED"
     
+    CONST_L2_ENCAP_TYPE_VXLAN = "VXLAN"
+    
     CONST_USE_GLOBAL_MAC_ENTERPRISE_DEFAULT = "ENTERPRISE_DEFAULT"
     
     CONST_ENCRYPTION_INHERITED = "INHERITED"
@@ -167,6 +174,8 @@ class NUSubnet(NURESTObject):
     
     CONST_MULTICAST_INHERITED = "INHERITED"
     
+    CONST_L2_ENCAP_TYPE_MPLSOUDP = "MPLSoUDP"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_DHCP_RELAY_STATUS_ENABLED = "ENABLED"
@@ -175,6 +184,8 @@ class NUSubnet(NURESTObject):
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_L2_ENCAP_TYPE_MPLS = "MPLS"
+    
     CONST_ENCRYPTION_DISABLED = "DISABLED"
     
     CONST_DPI_DISABLED = "DISABLED"
@@ -208,6 +219,7 @@ class NUSubnet(NURESTObject):
 
         # Read/Write Attributes
         
+        self._l2_encap_type = None
         self._pat_enabled = None
         self._dhcp_relay_status = None
         self._dpi = None
@@ -218,7 +230,6 @@ class NUSubnet(NURESTObject):
         self._maintenance_mode = None
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._gateway = None
         self._gateway_mac_address = None
         self._access_restriction_enabled = None
@@ -246,7 +257,6 @@ class NUSubnet(NURESTObject):
         self._route_distinguisher = None
         self._route_target = None
         self._split_subnet = None
-        self._creation_date = None
         self._proxy_arp = None
         self._vrrp_ipv6_backup_address = None
         self._use_global_mac = None
@@ -258,9 +268,9 @@ class NUSubnet(NURESTObject):
         self._multi_home_enabled = None
         self._multicast = None
         self._customer_id = None
-        self._owner = None
         self._external_id = None
         
+        self.expose_attribute(local_name="l2_encap_type", remote_name="l2EncapType", attribute_type=str, is_required=False, is_unique=False, choices=[u'MPLS', u'MPLSoUDP', u'VLAN', u'VXLAN'])
         self.expose_attribute(local_name="pat_enabled", remote_name="PATEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="dhcp_relay_status", remote_name="DHCPRelayStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
@@ -271,7 +281,6 @@ class NUSubnet(NURESTObject):
         self.expose_attribute(local_name="maintenance_mode", remote_name="maintenanceMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENABLED_INHERITED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_mac_address", remote_name="gatewayMACAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="access_restriction_enabled", remote_name="accessRestrictionEnabled", attribute_type=bool, is_required=False, is_unique=False)
@@ -299,7 +308,6 @@ class NUSubnet(NURESTObject):
         self.expose_attribute(local_name="route_distinguisher", remote_name="routeDistinguisher", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="route_target", remote_name="routeTarget", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="split_subnet", remote_name="splitSubnet", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="proxy_arp", remote_name="proxyARP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrrp_ipv6_backup_address", remote_name="vrrpIPv6BackupAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENTERPRISE_DEFAULT'])
@@ -311,7 +319,6 @@ class NUSubnet(NURESTObject):
         self.expose_attribute(local_name="multi_home_enabled", remote_name="multiHomeEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -363,6 +370,9 @@ class NUSubnet(NURESTObject):
         self.vm_interfaces = NUVMInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.vmip_reservations = NUVMIPReservationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.enterprise_permissions = NUEnterprisePermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -400,12 +410,39 @@ class NUSubnet(NURESTObject):
 
     # Properties
     
+    @property
+    def l2_encap_type(self):
+        """ Get l2_encap_type value.
+
+            Notes:
+                Subnet Tunnel Type, possible values are MPLS, MPLSoUDP, VLAN and VXLAN.
+
+                
+                This attribute is named `l2EncapType` in VSD API.
+                
+        """
+        return self._l2_encap_type
+
+    @l2_encap_type.setter
+    def l2_encap_type(self, value):
+        """ Set l2_encap_type value.
+
+            Notes:
+                Subnet Tunnel Type, possible values are MPLS, MPLSoUDP, VLAN and VXLAN.
+
+                
+                This attribute is named `l2EncapType` in VSD API.
+                
+        """
+        self._l2_encap_type = value
+
+    
     @property
     def pat_enabled(self):
         """ Get pat_enabled value.
 
             Notes:
-                Indicates whether PAT is enabled for the subnets in this domain - ENABLED/DISABLED. Possible values are ENABLED, DISABLED. OR INHERITED
+                None
 
                 
                 This attribute is named `PATEnabled` in VSD API.
@@ -418,7 +455,7 @@ class NUSubnet(NURESTObject):
         """ Set pat_enabled value.
 
             Notes:
-                Indicates whether PAT is enabled for the subnets in this domain - ENABLED/DISABLED. Possible values are ENABLED, DISABLED. OR INHERITED
+                None
 
                 
                 This attribute is named `PATEnabled` in VSD API.
@@ -666,33 +703,6 @@ class NUSubnet(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def gateway(self):
         """ Get gateway value.
@@ -1390,33 +1400,6 @@ class NUSubnet(NURESTObject):
         self._split_subnet = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def proxy_arp(self):
         """ Get proxy_arp value.
@@ -1706,29 +1689,6 @@ class NUSubnet(NURESTObject):
         self._customer_id = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
