@@ -120,22 +120,21 @@ class NUSubnetTemplate(NURESTObject):
         self._ipv6_gateway = None
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._gateway = None
         self._address = None
         self._description = None
         self._netmask = None
         self._embedded_metadata = None
+        self._enable_dhcpv4 = None
+        self._enable_dhcpv6 = None
         self._encryption = None
         self._entity_scope = None
         self._split_subnet = None
-        self._creation_date = None
         self._proxy_arp = None
         self._use_global_mac = None
         self._associated_multicast_channel_map_id = None
         self._dual_stack_dynamic_ip_allocation = None
         self._multicast = None
-        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
@@ -144,22 +143,21 @@ class NUSubnetTemplate(NURESTObject):
         self.expose_attribute(local_name="ipv6_gateway", remote_name="IPv6Gateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="netmask", remote_name="netmask", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="enable_dhcpv4", remote_name="enableDHCPv4", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="enable_dhcpv6", remote_name="enableDHCPv6", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption", remote_name="encryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="split_subnet", remote_name="splitSubnet", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="proxy_arp", remote_name="proxyARP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENTERPRISE_DEFAULT'])
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dual_stack_dynamic_ip_allocation", remote_name="dualStackDynamicIPAllocation", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -346,33 +344,6 @@ class NUSubnetTemplate(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def gateway(self):
         """ Get gateway value.
@@ -492,6 +463,60 @@ class NUSubnetTemplate(NURESTObject):
         self._embedded_metadata = value
 
     
+    @property
+    def enable_dhcpv4(self):
+        """ Get enable_dhcpv4 value.
+
+            Notes:
+                This value indicates whether IPv4 DHCP is enabled or not. This is applicable in case the subnet is DUALSTACK or IPv4
+
+                
+                This attribute is named `enableDHCPv4` in VSD API.
+                
+        """
+        return self._enable_dhcpv4
+
+    @enable_dhcpv4.setter
+    def enable_dhcpv4(self, value):
+        """ Set enable_dhcpv4 value.
+
+            Notes:
+                This value indicates whether IPv4 DHCP is enabled or not. This is applicable in case the subnet is DUALSTACK or IPv4
+
+                
+                This attribute is named `enableDHCPv4` in VSD API.
+                
+        """
+        self._enable_dhcpv4 = value
+
+    
+    @property
+    def enable_dhcpv6(self):
+        """ Get enable_dhcpv6 value.
+
+            Notes:
+                This value indicates whether IPv6 DHCP is enabled or not. This is applicable in case the subnet is DUALSTACK or IPv6
+
+                
+                This attribute is named `enableDHCPv6` in VSD API.
+                
+        """
+        return self._enable_dhcpv6
+
+    @enable_dhcpv6.setter
+    def enable_dhcpv6(self, value):
+        """ Set enable_dhcpv6 value.
+
+            Notes:
+                This value indicates whether IPv6 DHCP is enabled or not. This is applicable in case the subnet is DUALSTACK or IPv6
+
+                
+                This attribute is named `enableDHCPv6` in VSD API.
+                
+        """
+        self._enable_dhcpv6 = value
+
+    
     @property
     def encryption(self):
         """ Get encryption value.
@@ -569,33 +594,6 @@ class NUSubnetTemplate(NURESTObject):
         self._split_subnet = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def proxy_arp(self):
         """ Get proxy_arp value.
@@ -727,29 +725,6 @@ class NUSubnetTemplate(NURESTObject):
         self._multicast = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
