@@ -65,6 +65,8 @@ class NUTCA(NURESTObject):
     
     CONST_METRIC_TCP_FLAG_RST_IN = "TCP_FLAG_RST_IN"
     
+    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    
     CONST_METRIC_TCP_FLAG_ACK_OUT = "TCP_FLAG_ACK_OUT"
     
     CONST_METRIC_PORT_SWEEP_IP_COUNT = "PORT_SWEEP_IP_COUNT"
@@ -113,7 +115,7 @@ class NUTCA(NURESTObject):
     
     CONST_METRIC_L7_BYTES_IN = "L7_BYTES_IN"
     
-    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    CONST_ACTION_ALERT_ADD_NETWORK_MACRO = "Alert_Add_Network_Macro"
     
     CONST_METRIC_TCP_FLAG_SYN_OUT = "TCP_FLAG_SYN_OUT"
     
@@ -150,9 +152,9 @@ class NUTCA(NURESTObject):
         
         self._url_end_point = None
         self._name = None
+        self._target_entity_id = None
         self._target_policy_group_id = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._action = None
         self._period = None
         self._description = None
@@ -164,18 +166,17 @@ class NUTCA(NURESTObject):
         self._embedded_metadata = None
         self._entity_scope = None
         self._count = None
-        self._creation_date = None
+        self._trigger_interval = None
         self._status = None
-        self._owner = None
         self._external_id = None
         self._type = None
         
         self.expose_attribute(local_name="url_end_point", remote_name="URLEndPoint", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="target_entity_id", remote_name="targetEntityID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="target_policy_group_id", remote_name="targetPolicyGroupID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=True, is_unique=False, choices=[u'Alert', u'Alert_Add_Policy_Group', u'Alert_PolicyGroupChange'])
+        self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=True, is_unique=False, choices=[u'Alert', u'Alert_Add_Network_Macro', u'Alert_Add_Policy_Group', u'Alert_PolicyGroupChange'])
         self.expose_attribute(local_name="period", remote_name="period", attribute_type=int, is_required=True, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="metric", remote_name="metric", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACL_DENY_EVENT_COUNT', u'ANTI_SPOOF_EVENT_COUNT', u'BYTES_IN', u'BYTES_OUT', u'FIP_PRE_RATE_LIMIT_BYTES', u'FIP_PRE_RATE_LIMIT_PACKETS', u'FIP_RATE_LIMIT_DROPPED_BYTES', u'FIP_RATE_LIMIT_DROPPED_PACKETS', u'L7_BYTES_IN', u'L7_BYTES_OUT', u'L7_PACKETS_IN', u'L7_PACKETS_OUT', u'PACKETS_DROPPED_BY_RATE_LIMIT', u'PACKETS_IN', u'PACKETS_IN_DROPPED', u'PACKETS_IN_ERROR', u'PACKETS_OUT', u'PACKETS_OUT_DROPPED', u'PACKETS_OUT_ERROR', u'PORT_SCAN_PORT_COUNT', u'PORT_SWEEP_IP_COUNT', u'TCP_FLAG_ACK_IN', u'TCP_FLAG_ACK_OUT', u'TCP_FLAG_NULL_IN', u'TCP_FLAG_NULL_OUT', u'TCP_FLAG_RST_IN', u'TCP_FLAG_RST_OUT', u'TCP_FLAG_SYN_IN', u'TCP_FLAG_SYN_OUT'])
@@ -186,9 +187,8 @@ class NUTCA(NURESTObject):
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="count", remote_name="count", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="trigger_interval", remote_name="triggerInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=True, is_unique=False, choices=[u'BREACH', u'ROLLING_AVERAGE', u'UNIQUE_COUNT'])
         
@@ -262,12 +262,39 @@ class NUTCA(NURESTObject):
         self._name = value
 
     
+    @property
+    def target_entity_id(self):
+        """ Get target_entity_id value.
+
+            Notes:
+                ID of the target VSD entity used by the TCA action
+
+                
+                This attribute is named `targetEntityID` in VSD API.
+                
+        """
+        return self._target_entity_id
+
+    @target_entity_id.setter
+    def target_entity_id(self, value):
+        """ Set target_entity_id value.
+
+            Notes:
+                ID of the target VSD entity used by the TCA action
+
+                
+                This attribute is named `targetEntityID` in VSD API.
+                
+        """
+        self._target_entity_id = value
+
+    
     @property
     def target_policy_group_id(self):
         """ Get target_policy_group_id value.
 
             Notes:
-                Target policygroup when TCA is triggered
+                Target policygroup used by the TCA action
 
                 
                 This attribute is named `targetPolicyGroupID` in VSD API.
@@ -280,7 +307,7 @@ class NUTCA(NURESTObject):
         """ Set target_policy_group_id value.
 
             Notes:
-                Target policygroup when TCA is triggered
+                Target policygroup used by the TCA action
 
                 
                 This attribute is named `targetPolicyGroupID` in VSD API.
@@ -316,33 +343,6 @@ class NUTCA(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def action(self):
         """ Get action value.
@@ -463,7 +463,7 @@ class NUTCA(NURESTObject):
         """ Get throttle_time value.
 
             Notes:
-                Throttle time in secs
+                Throttle time in seconds
 
                 
                 This attribute is named `throttleTime` in VSD API.
@@ -476,7 +476,7 @@ class NUTCA(NURESTObject):
         """ Set throttle_time value.
 
             Notes:
-                Throttle time in secs
+                Throttle time in seconds
 
                 
                 This attribute is named `throttleTime` in VSD API.
@@ -613,30 +613,30 @@ class NUTCA(NURESTObject):
 
     
     @property
-    def creation_date(self):
-        """ Get creation_date value.
+    def trigger_interval(self):
+        """ Get trigger_interval value.
 
             Notes:
-                Time stamp when this object was created.
+                The trigger interval of the ES watch corresponding to this TCA, in seconds
 
                 
-                This attribute is named `creationDate` in VSD API.
+                This attribute is named `triggerInterval` in VSD API.
                 
         """
-        return self._creation_date
+        return self._trigger_interval
 
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
+    @trigger_interval.setter
+    def trigger_interval(self, value):
+        """ Set trigger_interval value.
 
             Notes:
-                Time stamp when this object was created.
+                The trigger interval of the ES watch corresponding to this TCA, in seconds
 
                 
-                This attribute is named `creationDate` in VSD API.
+                This attribute is named `triggerInterval` in VSD API.
                 
         """
-        self._creation_date = value
+        self._trigger_interval = value
 
     
     @property
@@ -662,29 +662,6 @@ class NUTCA(NURESTObject):
         self._status = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
