@@ -49,20 +49,44 @@ class NUTestRun(NURESTObject):
     
     ## Constants
     
+    CONST_TEST_RESULT_DATA_TYPE_MTUDISCOVERYTESTRESULT = "MTUDiscoveryTestResult"
+    
     CONST_OPERATION_STATUS_STARTED = "STARTED"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_OPERATION_STATUS_FAILED = "FAILED"
+    
+    CONST_TEST_RESULT_DATA_TYPE_TCPCONNECTTESTRESULT = "TCPConnectTestResult"
+    
+    CONST_TEST_RESULT_DATA_TYPE_BANDWIDTHTESTRESULT = "BandwidthTestResult"
+    
+    CONST_TEST_RESULT_NOT_APPLICABLE = "NOT_APPLICABLE"
+    
+    CONST_UNDERLAY_TEST_CATEGORY_BANDWIDTH = "BANDWIDTH"
+    
+    CONST_TEST_RESULT_FAIL = "FAIL"
+    
     CONST_OPERATION_STATUS_UNKNOWN = "UNKNOWN"
     
-    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    CONST_UNDERLAY_TEST_CATEGORY_CONNECTIVITY = "CONNECTIVITY"
     
-    CONST_OPERATION_STATUS_FAILED = "FAILED"
+    CONST_TEST_RESULT_PASS = "PASS"
+    
+    CONST_TEST_RESULT_DATA_TYPE_NONE = "None"
+    
+    CONST_TEST_RESULT_DATA_TYPE_UDPPROBETESTRESULT = "UDPProbeTestResult"
     
     CONST_OPERATION_STATUS_COMPLETED = "COMPLETED"
     
+    CONST_TEST_RESULT_DEGRADED = "DEGRADED"
+    
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
     CONST_OPERATION_STATUS_TIMED_OUT = "TIMED_OUT"
     
+    CONST_UNDERLAY_TEST_CATEGORY_MTU_DISCOVERY = "MTU_DISCOVERY"
+    
     
 
     def __init__(self, **kwargs):
@@ -83,39 +107,47 @@ class NUTestRun(NURESTObject):
         # Read/Write Attributes
         
         self._last_updated_by = None
-        self._last_updated_date = None
+        self._test_result = None
+        self._test_result_data = None
+        self._test_result_data_type = None
+        self._test_result_specification_entity_name = None
         self._embedded_metadata = None
+        self._underlay_test_category = None
+        self._underlay_test_description = None
+        self._underlay_test_name = None
         self._entity_scope = None
         self._command = None
         self._command_exit_code = None
         self._command_output = None
         self._command_output_summary = None
         self._operation_status = None
-        self._creation_date = None
         self._associated_test_id = None
         self._associated_test_suite_run_id = None
         self._start_date_time = None
         self._stop_date_time = None
         self._duration = None
-        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="test_result", remote_name="testResult", attribute_type=str, is_required=False, is_unique=False, choices=[u'DEGRADED', u'FAIL', u'NOT_APPLICABLE', u'PASS'])
+        self.expose_attribute(local_name="test_result_data", remote_name="testResultData", attribute_type=dict, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="test_result_data_type", remote_name="testResultDataType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BandwidthTestResult', u'MTUDiscoveryTestResult', u'None', u'TCPConnectTestResult', u'UDPProbeTestResult'])
+        self.expose_attribute(local_name="test_result_specification_entity_name", remote_name="testResultSpecificationEntityName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="underlay_test_category", remote_name="underlayTestCategory", attribute_type=str, is_required=False, is_unique=False, choices=[u'BANDWIDTH', u'CONNECTIVITY', u'MTU_DISCOVERY'])
+        self.expose_attribute(local_name="underlay_test_description", remote_name="underlayTestDescription", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="underlay_test_name", remote_name="underlayTestName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="command", remote_name="command", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="command_exit_code", remote_name="commandExitCode", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="command_output", remote_name="commandOutput", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="command_output_summary", remote_name="commandOutputSummary", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="operation_status", remote_name="operationStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'COMPLETED', u'FAILED', u'STARTED', u'TIMED_OUT', u'UNKNOWN'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_test_id", remote_name="associatedTestID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_test_suite_run_id", remote_name="associatedTestSuiteRunID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="start_date_time", remote_name="startDateTime", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stop_date_time", remote_name="stopDateTime", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="duration", remote_name="duration", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -160,30 +192,111 @@ class NUTestRun(NURESTObject):
 
     
     @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
+    def test_result(self):
+        """ Get test_result value.
 
             Notes:
-                Time stamp when this object was last updated.
+                The result of the test
 
                 
-                This attribute is named `lastUpdatedDate` in VSD API.
+                This attribute is named `testResult` in VSD API.
                 
         """
-        return self._last_updated_date
+        return self._test_result
 
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
+    @test_result.setter
+    def test_result(self, value):
+        """ Set test_result value.
 
             Notes:
-                Time stamp when this object was last updated.
+                The result of the test
 
                 
-                This attribute is named `lastUpdatedDate` in VSD API.
+                This attribute is named `testResult` in VSD API.
                 
         """
-        self._last_updated_date = value
+        self._test_result = value
+
+    
+    @property
+    def test_result_data(self):
+        """ Get test_result_data value.
+
+            Notes:
+                The test result data
+
+                
+                This attribute is named `testResultData` in VSD API.
+                
+        """
+        return self._test_result_data
+
+    @test_result_data.setter
+    def test_result_data(self, value):
+        """ Set test_result_data value.
+
+            Notes:
+                The test result data
+
+                
+                This attribute is named `testResultData` in VSD API.
+                
+        """
+        self._test_result_data = value
+
+    
+    @property
+    def test_result_data_type(self):
+        """ Get test_result_data_type value.
+
+            Notes:
+                The type of the data embedded in the testResultData attribute
+
+                
+                This attribute is named `testResultDataType` in VSD API.
+                
+        """
+        return self._test_result_data_type
+
+    @test_result_data_type.setter
+    def test_result_data_type(self, value):
+        """ Set test_result_data_type value.
+
+            Notes:
+                The type of the data embedded in the testResultData attribute
+
+                
+                This attribute is named `testResultDataType` in VSD API.
+                
+        """
+        self._test_result_data_type = value
+
+    
+    @property
+    def test_result_specification_entity_name(self):
+        """ Get test_result_specification_entity_name value.
+
+            Notes:
+                The spefication entity name of the data embedded in the testResultData attribute
+
+                
+                This attribute is named `testResultSpecificationEntityName` in VSD API.
+                
+        """
+        return self._test_result_specification_entity_name
+
+    @test_result_specification_entity_name.setter
+    def test_result_specification_entity_name(self, value):
+        """ Set test_result_specification_entity_name value.
+
+            Notes:
+                The spefication entity name of the data embedded in the testResultData attribute
+
+                
+                This attribute is named `testResultSpecificationEntityName` in VSD API.
+                
+        """
+        self._test_result_specification_entity_name = value
 
     
     @property
@@ -213,6 +326,87 @@ class NUTestRun(NURESTObject):
         self._embedded_metadata = value
 
     
+    @property
+    def underlay_test_category(self):
+        """ Get underlay_test_category value.
+
+            Notes:
+                The underlay test category
+
+                
+                This attribute is named `underlayTestCategory` in VSD API.
+                
+        """
+        return self._underlay_test_category
+
+    @underlay_test_category.setter
+    def underlay_test_category(self, value):
+        """ Set underlay_test_category value.
+
+            Notes:
+                The underlay test category
+
+                
+                This attribute is named `underlayTestCategory` in VSD API.
+                
+        """
+        self._underlay_test_category = value
+
+    
+    @property
+    def underlay_test_description(self):
+        """ Get underlay_test_description value.
+
+            Notes:
+                The underlay test description
+
+                
+                This attribute is named `underlayTestDescription` in VSD API.
+                
+        """
+        return self._underlay_test_description
+
+    @underlay_test_description.setter
+    def underlay_test_description(self, value):
+        """ Set underlay_test_description value.
+
+            Notes:
+                The underlay test description
+
+                
+                This attribute is named `underlayTestDescription` in VSD API.
+                
+        """
+        self._underlay_test_description = value
+
+    
+    @property
+    def underlay_test_name(self):
+        """ Get underlay_test_name value.
+
+            Notes:
+                The underlay test name
+
+                
+                This attribute is named `underlayTestName` in VSD API.
+                
+        """
+        return self._underlay_test_name
+
+    @underlay_test_name.setter
+    def underlay_test_name(self, value):
+        """ Set underlay_test_name value.
+
+            Notes:
+                The underlay test name
+
+                
+                This attribute is named `underlayTestName` in VSD API.
+                
+        """
+        self._underlay_test_name = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -371,33 +565,6 @@ class NUTestRun(NURESTObject):
         self._operation_status = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def associated_test_id(self):
         """ Get associated_test_id value.
@@ -529,29 +696,6 @@ class NUTestRun(NURESTObject):
         self._duration = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
