@@ -78,16 +78,16 @@ class NUUserContext(NURESTObject):
         self._vss_stats_interval = None
         self._page_size = None
         self._last_updated_by = None
-        self._last_updated_date = None
+        self._denied_flow_collection_enabled = None
+        self._threat_intelligence_enabled = None
         self._flow_collection_enabled = None
         self._embedded_metadata = None
         self._entity_scope = None
         self._google_maps_api_key = None
-        self._creation_date = None
         self._statistics_enabled = None
         self._stats_database_proxy = None
         self._stats_tsdb_server_address = None
-        self._owner = None
+        self._explicit_acl_matching_enabled = None
         self._external_id = None
         
         self.expose_attribute(local_name="aar_flow_stats_interval", remote_name="AARFlowStatsInterval", attribute_type=int, is_required=False, is_unique=False)
@@ -96,16 +96,16 @@ class NUUserContext(NURESTObject):
         self.expose_attribute(local_name="vss_stats_interval", remote_name="VSSStatsInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="page_size", remote_name="pageSize", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="denied_flow_collection_enabled", remote_name="deniedFlowCollectionEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="threat_intelligence_enabled", remote_name="threatIntelligenceEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="flow_collection_enabled", remote_name="flowCollectionEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="google_maps_api_key", remote_name="googleMapsAPIKey", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="statistics_enabled", remote_name="statisticsEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_database_proxy", remote_name="statsDatabaseProxy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_tsdb_server_address", remote_name="statsTSDBServerAddress", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="explicit_acl_matching_enabled", remote_name="explicitACLMatchingEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -285,30 +285,57 @@ class NUUserContext(NURESTObject):
 
     
     @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
+    def denied_flow_collection_enabled(self):
+        """ Get denied_flow_collection_enabled value.
 
             Notes:
-                Time stamp when this object was last updated.
+                When this option is selected, VSS will only store flows that are denied by security policy (implicit or explicit ACLs). This requires a valid VSS license and Flow Collection enabled.
 
                 
-                This attribute is named `lastUpdatedDate` in VSD API.
+                This attribute is named `deniedFlowCollectionEnabled` in VSD API.
                 
         """
-        return self._last_updated_date
+        return self._denied_flow_collection_enabled
 
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
+    @denied_flow_collection_enabled.setter
+    def denied_flow_collection_enabled(self, value):
+        """ Set denied_flow_collection_enabled value.
 
             Notes:
-                Time stamp when this object was last updated.
+                When this option is selected, VSS will only store flows that are denied by security policy (implicit or explicit ACLs). This requires a valid VSS license and Flow Collection enabled.
 
                 
-                This attribute is named `lastUpdatedDate` in VSD API.
+                This attribute is named `deniedFlowCollectionEnabled` in VSD API.
                 
         """
-        self._last_updated_date = value
+        self._denied_flow_collection_enabled = value
+
+    
+    @property
+    def threat_intelligence_enabled(self):
+        """ Get threat_intelligence_enabled value.
+
+            Notes:
+                Enables IP based threat intelligence. This requires Flow Collection to be enabled
+
+                
+                This attribute is named `threatIntelligenceEnabled` in VSD API.
+                
+        """
+        return self._threat_intelligence_enabled
+
+    @threat_intelligence_enabled.setter
+    def threat_intelligence_enabled(self, value):
+        """ Set threat_intelligence_enabled value.
+
+            Notes:
+                Enables IP based threat intelligence. This requires Flow Collection to be enabled
+
+                
+                This attribute is named `threatIntelligenceEnabled` in VSD API.
+                
+        """
+        self._threat_intelligence_enabled = value
 
     
     @property
@@ -419,33 +446,6 @@ class NUUserContext(NURESTObject):
         self._google_maps_api_key = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def statistics_enabled(self):
         """ Get statistics_enabled value.
@@ -528,26 +528,30 @@ class NUUserContext(NURESTObject):
 
     
     @property
-    def owner(self):
-        """ Get owner value.
+    def explicit_acl_matching_enabled(self):
+        """ Get explicit_acl_matching_enabled value.
 
             Notes:
-                Identifies the user that has created this object.
+                When this option is selected, VSS will only store allow/denied flows that matches explicit ingress/egress security ACL. This requires a valid VSS license and Flow Collection enabled.
 
                 
+                This attribute is named `explicitACLMatchingEnabled` in VSD API.
+                
         """
-        return self._owner
+        return self._explicit_acl_matching_enabled
 
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
+    @explicit_acl_matching_enabled.setter
+    def explicit_acl_matching_enabled(self, value):
+        """ Set explicit_acl_matching_enabled value.
 
             Notes:
-                Identifies the user that has created this object.
+                When this option is selected, VSS will only store allow/denied flows that matches explicit ingress/egress security ACL. This requires a valid VSS license and Flow Collection enabled.
 
                 
+                This attribute is named `explicitACLMatchingEnabled` in VSD API.
+                
         """
-        self._owner = value
+        self._explicit_acl_matching_enabled = value
 
     
     @property
