@@ -87,7 +87,6 @@ class NUVirtualFirewallPolicy(NURESTObject):
         
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._active = None
         self._default_allow_ip = None
         self._default_allow_non_ip = None
@@ -97,19 +96,18 @@ class NUVirtualFirewallPolicy(NURESTObject):
         self._embedded_metadata = None
         self._entity_scope = None
         self._policy_state = None
-        self._creation_date = None
         self._priority = None
         self._priority_type = None
+        self._associated_egress_adv_fwd_rule_template_id = None
         self._associated_egress_template_id = None
+        self._associated_ingress_adv_fwd_rule_template_id = None
         self._associated_ingress_template_id = None
         self._associated_live_entity_id = None
         self._auto_generate_priority = None
-        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="active", remote_name="active", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="default_allow_ip", remote_name="defaultAllowIP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="default_allow_non_ip", remote_name="defaultAllowNonIP", attribute_type=bool, is_required=False, is_unique=False)
@@ -119,14 +117,14 @@ class NUVirtualFirewallPolicy(NURESTObject):
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="policy_state", remote_name="policyState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DRAFT', u'LIVE'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="priority", remote_name="priority", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="priority_type", remote_name="priorityType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BOTTOM', u'NONE', u'TOP'])
+        self.expose_attribute(local_name="associated_egress_adv_fwd_rule_template_id", remote_name="associatedEgressAdvFwdRuleTemplateID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_egress_template_id", remote_name="associatedEgressTemplateID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_ingress_adv_fwd_rule_template_id", remote_name="associatedIngressAdvFwdRuleTemplateID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_ingress_template_id", remote_name="associatedIngressTemplateID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_live_entity_id", remote_name="associatedLiveEntityID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="auto_generate_priority", remote_name="autoGeneratePriority", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -196,33 +194,6 @@ class NUVirtualFirewallPolicy(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def active(self):
         """ Get active value.
@@ -458,33 +429,6 @@ class NUVirtualFirewallPolicy(NURESTObject):
         self._policy_state = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def priority(self):
         """ Get priority value.
@@ -535,6 +479,33 @@ class NUVirtualFirewallPolicy(NURESTObject):
         self._priority_type = value
 
     
+    @property
+    def associated_egress_adv_fwd_rule_template_id(self):
+        """ Get associated_egress_adv_fwd_rule_template_id value.
+
+            Notes:
+                The read only id of the auto generated Egress Advance Forwarding Rule Template ID
+
+                
+                This attribute is named `associatedEgressAdvFwdRuleTemplateID` in VSD API.
+                
+        """
+        return self._associated_egress_adv_fwd_rule_template_id
+
+    @associated_egress_adv_fwd_rule_template_id.setter
+    def associated_egress_adv_fwd_rule_template_id(self, value):
+        """ Set associated_egress_adv_fwd_rule_template_id value.
+
+            Notes:
+                The read only id of the auto generated Egress Advance Forwarding Rule Template ID
+
+                
+                This attribute is named `associatedEgressAdvFwdRuleTemplateID` in VSD API.
+                
+        """
+        self._associated_egress_adv_fwd_rule_template_id = value
+
+    
     @property
     def associated_egress_template_id(self):
         """ Get associated_egress_template_id value.
@@ -562,6 +533,33 @@ class NUVirtualFirewallPolicy(NURESTObject):
         self._associated_egress_template_id = value
 
     
+    @property
+    def associated_ingress_adv_fwd_rule_template_id(self):
+        """ Get associated_ingress_adv_fwd_rule_template_id value.
+
+            Notes:
+                The read only id of the auto generated Ingress Advance Forwarding Rule Template ID
+
+                
+                This attribute is named `associatedIngressAdvFwdRuleTemplateID` in VSD API.
+                
+        """
+        return self._associated_ingress_adv_fwd_rule_template_id
+
+    @associated_ingress_adv_fwd_rule_template_id.setter
+    def associated_ingress_adv_fwd_rule_template_id(self, value):
+        """ Set associated_ingress_adv_fwd_rule_template_id value.
+
+            Notes:
+                The read only id of the auto generated Ingress Advance Forwarding Rule Template ID
+
+                
+                This attribute is named `associatedIngressAdvFwdRuleTemplateID` in VSD API.
+                
+        """
+        self._associated_ingress_adv_fwd_rule_template_id = value
+
+    
     @property
     def associated_ingress_template_id(self):
         """ Get associated_ingress_template_id value.
@@ -643,29 +641,6 @@ class NUVirtualFirewallPolicy(NURESTObject):
         self._auto_generate_priority = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
