@@ -75,27 +75,33 @@ class NUVNFDomainMapping(NURESTObject):
         # Read/Write Attributes
         
         self._last_updated_by = None
-        self._last_updated_date = None
         self._segmentation_id = None
         self._segmentation_type = None
+        self._service_id = None
         self._embedded_metadata = None
+        self._enterprise_name = None
         self._entity_scope = None
-        self._creation_date = None
+        self._associated_domain_id = None
+        self._associated_domain_name = None
+        self._associated_enterprise_id = None
         self._associated_ns_gateway_id = None
         self._associated_ns_gateway_name = None
-        self._owner = None
+        self._auto_created = None
         self._external_id = None
         
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="segmentation_id", remote_name="segmentationID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="segmentation_type", remote_name="segmentationType", attribute_type=str, is_required=False, is_unique=False, choices=[u'VLAN'])
+        self.expose_attribute(local_name="service_id", remote_name="serviceId", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_domain_id", remote_name="associatedDomainID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_domain_name", remote_name="associatedDomainName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_enterprise_id", remote_name="associatedEnterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_ns_gateway_id", remote_name="associatedNSGatewayID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_ns_gateway_name", remote_name="associatedNSGatewayName", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="auto_created", remote_name="autoCreated", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -139,33 +145,6 @@ class NUVNFDomainMapping(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def segmentation_id(self):
         """ Get segmentation_id value.
@@ -220,6 +199,33 @@ class NUVNFDomainMapping(NURESTObject):
         self._segmentation_type = value
 
     
+    @property
+    def service_id(self):
+        """ Get service_id value.
+
+            Notes:
+                Service ID of the associated Domain
+
+                
+                This attribute is named `serviceId` in VSD API.
+                
+        """
+        return self._service_id
+
+    @service_id.setter
+    def service_id(self, value):
+        """ Set service_id value.
+
+            Notes:
+                Service ID of the associated Domain
+
+                
+                This attribute is named `serviceId` in VSD API.
+                
+        """
+        self._service_id = value
+
+    
     @property
     def embedded_metadata(self):
         """ Get embedded_metadata value.
@@ -247,6 +253,33 @@ class NUVNFDomainMapping(NURESTObject):
         self._embedded_metadata = value
 
     
+    @property
+    def enterprise_name(self):
+        """ Get enterprise_name value.
+
+            Notes:
+                Name of the associated Enterprise
+
+                
+                This attribute is named `enterpriseName` in VSD API.
+                
+        """
+        return self._enterprise_name
+
+    @enterprise_name.setter
+    def enterprise_name(self, value):
+        """ Set enterprise_name value.
+
+            Notes:
+                Name of the associated Enterprise
+
+                
+                This attribute is named `enterpriseName` in VSD API.
+                
+        """
+        self._enterprise_name = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -275,30 +308,84 @@ class NUVNFDomainMapping(NURESTObject):
 
     
     @property
-    def creation_date(self):
-        """ Get creation_date value.
+    def associated_domain_id(self):
+        """ Get associated_domain_id value.
 
             Notes:
-                Time stamp when this object was created.
+                ID of the associated Domain
 
                 
-                This attribute is named `creationDate` in VSD API.
+                This attribute is named `associatedDomainID` in VSD API.
                 
         """
-        return self._creation_date
+        return self._associated_domain_id
 
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
+    @associated_domain_id.setter
+    def associated_domain_id(self, value):
+        """ Set associated_domain_id value.
 
             Notes:
-                Time stamp when this object was created.
+                ID of the associated Domain
 
                 
-                This attribute is named `creationDate` in VSD API.
+                This attribute is named `associatedDomainID` in VSD API.
                 
         """
-        self._creation_date = value
+        self._associated_domain_id = value
+
+    
+    @property
+    def associated_domain_name(self):
+        """ Get associated_domain_name value.
+
+            Notes:
+                Name of the associated Domain
+
+                
+                This attribute is named `associatedDomainName` in VSD API.
+                
+        """
+        return self._associated_domain_name
+
+    @associated_domain_name.setter
+    def associated_domain_name(self, value):
+        """ Set associated_domain_name value.
+
+            Notes:
+                Name of the associated Domain
+
+                
+                This attribute is named `associatedDomainName` in VSD API.
+                
+        """
+        self._associated_domain_name = value
+
+    
+    @property
+    def associated_enterprise_id(self):
+        """ Get associated_enterprise_id value.
+
+            Notes:
+                ID of the associated Enterprise
+
+                
+                This attribute is named `associatedEnterpriseID` in VSD API.
+                
+        """
+        return self._associated_enterprise_id
+
+    @associated_enterprise_id.setter
+    def associated_enterprise_id(self, value):
+        """ Set associated_enterprise_id value.
+
+            Notes:
+                ID of the associated Enterprise
+
+                
+                This attribute is named `associatedEnterpriseID` in VSD API.
+                
+        """
+        self._associated_enterprise_id = value
 
     
     @property
@@ -356,26 +443,30 @@ class NUVNFDomainMapping(NURESTObject):
 
     
     @property
-    def owner(self):
-        """ Get owner value.
+    def auto_created(self):
+        """ Get auto_created value.
 
             Notes:
-                Identifies the user that has created this object.
+                Indicates that this domain mapping was auto created by the system
 
                 
+                This attribute is named `autoCreated` in VSD API.
+                
         """
-        return self._owner
+        return self._auto_created
 
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
+    @auto_created.setter
+    def auto_created(self, value):
+        """ Set auto_created value.
 
             Notes:
-                Identifies the user that has created this object.
+                Indicates that this domain mapping was auto created by the system
 
                 
+                This attribute is named `autoCreated` in VSD API.
+                
         """
-        self._owner = value
+        self._auto_created = value
 
     
     @property
