@@ -34,6 +34,9 @@ from .fetchers import NUMetadatasFetcher
 from .fetchers import NUNetconfManagersFetcher
 
 
+from .fetchers import NUThreatPreventionServerConnectionsFetcher
+
+
 from .fetchers import NUGlobalMetadatasFetcher
 
 
@@ -86,26 +89,20 @@ class NUVSP(NURESTObject):
         
         self._name = None
         self._last_updated_by = None
-        self._last_updated_date = None
         self._description = None
         self._embedded_metadata = None
         self._entity_scope = None
         self._location = None
-        self._creation_date = None
         self._product_version = None
-        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="location", remote_name="location", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="product_version", remote_name="productVersion", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -118,6 +115,9 @@ class NUVSP(NURESTObject):
         self.netconf_managers = NUNetconfManagersFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.threat_prevention_server_connections = NUThreatPreventionServerConnectionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -184,33 +184,6 @@ class NUVSP(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_updated_date(self):
-        """ Get last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        return self._last_updated_date
-
-    @last_updated_date.setter
-    def last_updated_date(self, value):
-        """ Set last_updated_date value.
-
-            Notes:
-                Time stamp when this object was last updated.
-
-                
-                This attribute is named `lastUpdatedDate` in VSD API.
-                
-        """
-        self._last_updated_date = value
-
-    
     @property
     def description(self):
         """ Get description value.
@@ -311,33 +284,6 @@ class NUVSP(NURESTObject):
         self._location = value
 
     
-    @property
-    def creation_date(self):
-        """ Get creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        return self._creation_date
-
-    @creation_date.setter
-    def creation_date(self, value):
-        """ Set creation_date value.
-
-            Notes:
-                Time stamp when this object was created.
-
-                
-                This attribute is named `creationDate` in VSD API.
-                
-        """
-        self._creation_date = value
-
-    
     @property
     def product_version(self):
         """ Get product_version value.
@@ -365,29 +311,6 @@ class NUVSP(NURESTObject):
         self._product_version = value
 
     
-    @property
-    def owner(self):
-        """ Get owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        return self._owner
-
-    @owner.setter
-    def owner(self, value):
-        """ Set owner value.
-
-            Notes:
-                Identifies the user that has created this object.
-
-                
-        """
-        self._owner = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
